@@ -15,9 +15,8 @@
 //     OPL interface.
 //
 
-#include "SDL.h"
-
 #include <stdio.h>
+#include <string.h>
 
 #include "m_io.h"
 #include "opl.h"
@@ -34,7 +33,6 @@ static opl_driver_t *drivers[] =
 };
 
 static opl_driver_t *driver = NULL;
-static int init_stage_reg_writes = 1;
 
 unsigned int opl_sample_rate = 22050;
 
@@ -48,8 +46,6 @@ unsigned int opl_sample_rate = 22050;
 static opl_init_result_t InitDriver(opl_driver_t *_driver,
                                     unsigned int port_base)
 {
-    opl_init_result_t result1, result2;
-
     // Initialize the driver.
 
     if (!_driver->init_func(port_base))
@@ -63,23 +59,10 @@ static opl_init_result_t InitDriver(opl_driver_t *_driver,
     // (it's done twice, like how Doom does it).
 
     driver = _driver;
-    init_stage_reg_writes = 1;
-
-    result1 = OPL_Detect();
-    result2 = OPL_Detect();
-    if (result1 == OPL_INIT_NONE || result2 == OPL_INIT_NONE)
-    {
-        printf("OPL_Init: No OPL detected using '%s' driver.\n", _driver->name);
-        _driver->shutdown_func();
-        driver = NULL;
-        return OPL_INIT_NONE;
-    }
-
-    init_stage_reg_writes = 0;
 
     printf("OPL_Init: Using driver '%s'.\n", driver->name);
 
-    return result2;
+    return OPL_INIT_OPL3;
 }
 
 // Find a driver automatically by trying each in the list.
@@ -232,18 +215,7 @@ void OPL_WriteRegister(int reg, int value)
 
     for (i=0; i<6; ++i)
     {
-        // An oddity of the Doom OPL code: at startup initialization,
-        // the spacing here is performed by reading from the register
-        // port; after initialization, the data port is read, instead.
-
-        if (init_stage_reg_writes)
-        {
-            OPL_ReadPort(OPL_REGISTER_PORT);
-        }
-        else
-        {
-            OPL_ReadPort(OPL_DATA_PORT);
-        }
+        OPL_ReadPort(OPL_DATA_PORT);
     }
 
     OPL_WritePort(OPL_DATA_PORT, value);
@@ -257,66 +229,6 @@ void OPL_WriteRegister(int reg, int value)
     }
 }
 
-// Detect the presence of an OPL chip
-
-opl_init_result_t OPL_Detect(void)
-{
-    int result1, result2;
-    int i;
-
-    // Reset both timers:
-    OPL_WriteRegister(OPL_REG_TIMER_CTRL, 0x60);
-
-    // Enable interrupts:
-    OPL_WriteRegister(OPL_REG_TIMER_CTRL, 0x80);
-
-    // Read status
-    result1 = OPL_ReadStatus();
-
-    // Set timer:
-    OPL_WriteRegister(OPL_REG_TIMER1, 0xff);
-
-    // Start timer 1:
-    OPL_WriteRegister(OPL_REG_TIMER_CTRL, 0x21);
-
-    // Wait for 80 microseconds
-    // This is how Doom does it:
-
-    for (i=0; i<200; ++i)
-    {
-        OPL_ReadStatus();
-    }
-
-    OPL_Delay(1 * OPL_MS);
-
-    // Read status
-    result2 = OPL_ReadStatus();
-
-    // Reset both timers:
-    OPL_WriteRegister(OPL_REG_TIMER_CTRL, 0x60);
-
-    // Enable interrupts:
-    OPL_WriteRegister(OPL_REG_TIMER_CTRL, 0x80);
-
-    if ((result1 & 0xe0) == 0x00 && (result2 & 0xe0) == 0xc0)
-    {
-        result1 = OPL_ReadPort(OPL_REGISTER_PORT);
-        result2 = OPL_ReadPort(OPL_REGISTER_PORT_OPL3);
-        if (result1 == 0x00)
-        {
-            return OPL_INIT_OPL3;
-        }
-        else
-        {
-            return OPL_INIT_OPL2;
-        }
-    }
-    else
-    {
-        return OPL_INIT_NONE;
-    }
-}
-
 // Initialize registers on startup
 
 void OPL_InitRegisters(int opl3)
@@ -414,85 +326,6 @@ void OPL_ClearCallbacks(void)
     }
 }
 
-void OPL_Lock(void)
-{
-    if (driver != NULL)
-    {
-        driver->lock_func();
-    }
-}
-
-void OPL_Unlock(void)
-{
-    if (driver != NULL)
-    {
-        driver->unlock_func();
-    }
-}
-
-typedef struct
-{
-    int finished;
-
-    SDL_mutex *mutex;
-    SDL_cond *cond;
-} delay_data_t;
-
-static void DelayCallback(void *_delay_data)
-{
-    delay_data_t *delay_data = _delay_data;
-
-    SDL_LockMutex(delay_data->mutex);
-    delay_data->finished = 1;
-
-    SDL_CondSignal(delay_data->cond);
-
-    SDL_UnlockMutex(delay_data->mutex);
-}
-
-void OPL_Delay(uint64_t us)
-{
-    delay_data_t delay_data;
-
-    if (driver == NULL)
-    {
-        return;
-    }
-
-    // Create a callback that will signal this thread after the
-    // specified time.
-
-    delay_data.finished = 0;
-    delay_data.mutex = SDL_CreateMutex();
-    delay_data.cond = SDL_CreateCond();
-
-    OPL_SetCallback(us, DelayCallback, &delay_data);
-
-    // Wait until the callback is invoked.
-
-    SDL_LockMutex(delay_data.mutex);
-
-    while (!delay_data.finished)
-    {
-        SDL_CondWait(delay_data.cond, delay_data.mutex);
-    }
-
-    SDL_UnlockMutex(delay_data.mutex);
-
-    // Clean up.
-
-    SDL_DestroyMutex(delay_data.mutex);
-    SDL_DestroyCond(delay_data.cond);
-}
-
-void OPL_SetPaused(int paused)
-{
-    if (driver != NULL)
-    {
-        driver->set_paused_func(paused);
-    }
-}
-
 void OPL_AdjustCallbacks(float value)
 {
     if (driver != NULL)
