@@ -18,8 +18,8 @@
 #ifndef __D_IWAD__
 #define __D_IWAD__
 
-#include "doomtype.h"
 #include "doomdef.h"
+#include "doomtype.h"
 
 typedef struct
 {
@@ -30,12 +30,12 @@ typedef struct
     const char *description;
 } iwad_t;
 
-char *D_DoomExeDir(void);       // killough 2/16/98: path to executable's dir
+char *D_DoomExeDir(void); // killough 2/16/98: path to executable's dir
 char *D_FindWADByName(const char *filename);
 char *D_TryFindWADByName(const char *filename);
-char *D_FindIWADFile(GameMode_t *mode, GameMission_t *mission, GameVariant_t *variant);
+char *D_FindIWADFile(GameMode_t *mode, GameMission_t *mission,
+                     GameVariant_t *variant);
 boolean D_IsIWADName(const char *name);
 const iwad_t **D_GetIwads(void);
 
 #endif
-
