@@ -50,7 +50,7 @@ typedef struct
 // received before we bail out and render a frame anyway.
 // Vanilla Doom used 20 for this value, but we use a smaller value
 // instead for better responsiveness of the menu when we're stuck.
-#define MAX_NETGAME_STALL_TICS  5
+#define MAX_NETGAME_STALL_TICS 5
 
 //
 // gametic is the tic about to (or currently being) run
@@ -77,20 +77,20 @@ static int localplayer;
 
 // Used for original sync code.
 
-static int      skiptics = 0;
+static int skiptics = 0;
 
 // Reduce the bandwidth needed by sampling game input less and transmitting
 // less.  If ticdup is 2, sample half normal, 3 = one third normal, etc.
 
-int		ticdup;
+int ticdup;
 
 // Amount to offset the timer for game sync.
 
-fixed_t         offsetms;
+fixed_t offsetms;
 
 // Use new client syncronisation code
 
-static boolean  new_sync = true;
+static boolean new_sync = true;
 
 // Current players in the multiplayer game.
 // This is distinct from playeringame[] used by the game code, which may
@@ -104,7 +104,6 @@ static boolean local_playeringame[NET_MAXPLAYERS];
 
 static int player_class;
 
-
 // 35 fps clock adjusted by offsetms milliseconds
 
 static int GetAdjustedTime(void)
@@ -129,17 +128,17 @@ static int GetAdjustedTime(void)
 }
 
 void D_ProcessEvents(void);
-void G_BuildTiccmd(ticcmd_t* cmd);
+void G_BuildTiccmd(ticcmd_t *cmd);
 void M_Ticker(void);
 
 static boolean BuildNewTic(void)
 {
-    int	gameticdiv;
+    int gameticdiv;
     ticcmd_t cmd;
 
-    gameticdiv = gametic/ticdup;
+    gameticdiv = gametic / ticdup;
 
-    I_StartTic ();
+    I_StartTic();
     D_ProcessEvents();
 
     // Always run the menu
@@ -155,24 +154,30 @@ static boolean BuildNewTic(void)
 
     if (new_sync)
     {
-       // If playing single player, do not allow tics to buffer
-       // up very far
+        // If playing single player, do not allow tics to buffer
+        // up very far
 
-       if (!net_client_connected && maketic - gameticdiv > 2)
-           return false;
+        if (!net_client_connected && maketic - gameticdiv > 2)
+        {
+            return false;
+        }
 
-       // Never go more than ~200ms ahead
+        // Never go more than ~200ms ahead
 
-       if (maketic - gameticdiv > 8)
-           return false;
+        if (maketic - gameticdiv > 8)
+        {
+            return false;
+        }
     }
     else
     {
-       if (maketic - gameticdiv >= 5)
-           return false;
+        if (maketic - gameticdiv >= 5)
+        {
+            return false;
+        }
     }
 
-    //printf ("mk:%i ",maketic);
+    // printf ("mk:%i ",maketic);
     memset(&cmd, 0, sizeof(ticcmd_t));
     G_BuildTiccmd(&cmd);
 
@@ -194,19 +199,21 @@ static boolean BuildNewTic(void)
 // Builds ticcmds for console player,
 // sends out a packet
 //
-int      lasttime;
+int lasttime;
 
-void NetUpdate (void)
+void NetUpdate(void)
 {
     int nowtime;
     int newtics;
-    int	i;
+    int i;
 
     // If we are running with singletics (timing a demo), this
     // is all done separately.
 
     if (singletics)
+    {
         return;
+    }
 
     // Run network subsystems
 
@@ -232,7 +239,7 @@ void NetUpdate (void)
 
     // build new ticcmds for console player
 
-    for (i=0 ; i<newtics ; i++)
+    for (i = 0; i < newtics; i++)
     {
         if (!BuildNewTic())
         {
@@ -316,8 +323,9 @@ static void BlockUntilStart(net_gamesettings_t *settings,
             I_Error("Lost connection to server");
         }
 
-        if (callback != NULL && !callback(net_client_wait_data.ready_players,
-                                          net_client_wait_data.num_players))
+        if (callback != NULL
+            && !callback(net_client_wait_data.ready_players,
+                         net_client_wait_data.num_players))
         {
             I_Error("Netgame startup aborted.");
         }
@@ -344,6 +352,7 @@ void D_StartNetGame(net_gamesettings_t *settings,
     // Use original network client sync code rather than the improved
     // sync code.
     //
+
     settings->new_sync = !M_ParmExists("-oldsync");
 
     //!
@@ -357,9 +366,13 @@ void D_StartNetGame(net_gamesettings_t *settings,
     i = M_CheckParmWithArgs("-extratics", 1);
 
     if (i > 0)
+    {
         settings->extratics = M_ParmArgToInt(i);
+    }
     else
+    {
         settings->extratics = 1;
+    }
 
     //!
     // @category net
@@ -372,9 +385,13 @@ void D_StartNetGame(net_gamesettings_t *settings,
     i = M_CheckParmWithArgs("-dup", 1);
 
     if (i > 0)
+    {
         settings->ticdup = M_ParmArgToInt(i);
+    }
     else
+    {
         settings->ticdup = 1;
+    }
 
     if (net_client_connected)
     {
@@ -414,7 +431,7 @@ void D_StartNetGame(net_gamesettings_t *settings,
     }
 
     // TODO: Message disabled until we fix new_sync.
-    //if (!new_sync)
+    // if (!new_sync)
     //{
     //    printf("Syncing netgames like Vanilla Doom.\n");
     //}
@@ -439,8 +456,7 @@ boolean D_InitNetGame(net_connect_data_t *connect_data)
     // Start a multiplayer server, listening for connections.
     //
 
-    if (M_CheckParm("-server") > 0
-     || M_CheckParm("-privateserver") > 0)
+    if (M_CheckParm("-server") > 0 || M_CheckParm("-privateserver") > 0)
     {
         NET_SV_Init();
         NET_SV_AddModule(&net_loop_server_module);
@@ -487,12 +503,12 @@ boolean D_InitNetGame(net_connect_data_t *connect_data)
         if (i > 0)
         {
             net_sdl_module.InitClient();
-            addr = net_sdl_module.ResolveAddress(myargv[i+1]);
+            addr = net_sdl_module.ResolveAddress(myargv[i + 1]);
             NET_ReferenceAddress(addr);
 
             if (addr == NULL)
             {
-                I_Error("Unable to resolve '%s'\n", myargv[i+1]);
+                I_Error("Unable to resolve '%s'\n", myargv[i + 1]);
             }
         }
     }
@@ -510,7 +526,8 @@ boolean D_InitNetGame(net_connect_data_t *connect_data)
                     NET_AddrToString(addr), net_client_reject_reason);
         }
 
-        I_Printf(VB_INFO, "D_InitNetGame: Connected to %s", NET_AddrToString(addr));
+        I_Printf(VB_INFO, "D_InitNetGame: Connected to %s",
+                 NET_AddrToString(addr));
         NET_ReleaseAddress(addr);
 
         // Wait for launch message received from server.
@@ -537,7 +554,8 @@ void D_CheckNetPlaybackSkip(void)
 
     if (singletics || fastdemo || PLAYBACK_SKIP)
     {
-        I_Printf(VB_INFO, "Demo playback skipping is suppressed in network game.");
+        I_Printf(VB_INFO,
+                 "Demo playback skipping is suppressed in network game.");
         singletics = false;
         fastdemo = false;
         timingdemo = false;
@@ -551,7 +569,7 @@ void D_CheckNetPlaybackSkip(void)
 // Called before quitting to leave a net game
 // without hanging the other players
 //
-void D_QuitNetGame (void)
+void D_QuitNetGame(void)
 {
     NET_SV_Shutdown();
     NET_CL_Disconnect();
@@ -589,7 +607,7 @@ static void OldNetSync(void)
     // ideally maketic should be 1 - 3 tics above lowtic
     // if we are consistantly slower, speed up time
 
-    for (i=0 ; i<NET_MAXPLAYERS ; i++)
+    for (i = 0; i < NET_MAXPLAYERS; i++)
     {
         if (local_playeringame[i])
         {
@@ -667,7 +685,9 @@ int D_GetPlayersInNetGame(void)
         for (i = 0; i < NET_MAXPLAYERS; ++i)
         {
             if (local_playeringame[i])
+            {
                 ++result;
+            }
         }
     }
 
@@ -682,12 +702,14 @@ static void TicdupSquash(ticcmd_set_t *set)
     ticcmd_t *cmd;
     unsigned int i;
 
-    for (i = 0; i < NET_MAXPLAYERS ; ++i)
+    for (i = 0; i < NET_MAXPLAYERS; ++i)
     {
         cmd = &set->cmds[i];
         cmd->chatchar = 0;
         if (cmd->buttons & BT_SPECIAL)
+        {
             cmd->buttons = 0;
+        }
     }
 }
 
@@ -707,26 +729,25 @@ static void SinglePlayerClear(ticcmd_set_t *set)
     }
 }
 
-
 //
 // TryRunTics
 //
 
 void RunTic(ticcmd_t *cmds, boolean *ingame);
 
-void TryRunTics (void)
+void TryRunTics(void)
 {
-    int	i;
-    int	lowtic;
-    int	entertic;
+    int i;
+    int lowtic;
+    int entertic;
     static int oldentertics;
     int realtics;
-    int	availabletics;
-    int	counts;
+    int availabletics;
+    int counts;
 
-    // [AM] If we've uncapped the framerate and there are no tics
-    //      to run, return early instead of waiting around.
-    #define return_early (uncapped && counts == 0)
+// [AM] If we've uncapped the framerate and there are no tics
+//      to run, return early instead of waiting around.
+#define return_early (uncapped && counts == 0)
 
     // get real tics
     entertic = I_GetTime() / ticdup;
@@ -742,12 +763,12 @@ void TryRunTics (void)
     }
     else
     {
-        NetUpdate ();
+        NetUpdate();
     }
 
     lowtic = GetLowTic();
 
-    availabletics = lowtic - gametic/ticdup;
+    availabletics = lowtic - gametic / ticdup;
 
     // decide how many tics to run
 
@@ -758,25 +779,37 @@ void TryRunTics (void)
         // [AM] If we've uncapped the framerate and there are no tics
         //      to run, return early instead of waiting around.
         if (return_early)
+        {
             return;
+        }
     }
     else
     {
         // decide how many tics to run
-        if (realtics < availabletics-1)
-            counts = realtics+1;
+        if (realtics < availabletics - 1)
+        {
+            counts = realtics + 1;
+        }
         else if (realtics < availabletics)
+        {
             counts = realtics;
+        }
         else
+        {
             counts = availabletics;
+        }
 
         // [AM] If we've uncapped the framerate and there are no tics
         //      to run, return early instead of waiting around.
         if (return_early)
+        {
             return;
+        }
 
         if (counts < 1)
+        {
             counts = 1;
+        }
 
         if (net_client_connected)
         {
@@ -785,20 +818,24 @@ void TryRunTics (void)
     }
 
     if (counts < 1)
-	counts = 1;
+    {
+        counts = 1;
+    }
 
     // wait for new tics if needed
-    while (!PlayersInGame() || lowtic < gametic/ticdup + counts)
+    while (!PlayersInGame() || lowtic < gametic / ticdup + counts)
     {
-	NetUpdate ();
+        NetUpdate();
 
         lowtic = GetLowTic();
 
-	if (lowtic < gametic/ticdup)
-	    I_Error ("TryRunTics: lowtic < gametic");
+        if (lowtic < gametic / ticdup)
+        {
+            I_Error("TryRunTics: lowtic < gametic");
+        }
 
         // Still no tics to run? Sleep until some are available.
-        if (lowtic < gametic/ticdup + counts)
+        if (lowtic < gametic / ticdup + counts)
         {
             // If we're in a netgame, we might spin forever waiting for
             // new network data to be received. So don't stay in here
@@ -829,22 +866,24 @@ void TryRunTics (void)
             SinglePlayerClear(set);
         }
 
-	for (i=0 ; i<ticdup ; i++)
-	{
-            if (gametic/ticdup > lowtic)
-                I_Error ("gametic>lowtic");
+        for (i = 0; i < ticdup; i++)
+        {
+            if (gametic / ticdup > lowtic)
+            {
+                I_Error("gametic>lowtic");
+            }
 
             memcpy(local_playeringame, set->ingame, sizeof(local_playeringame));
 
             RunTic(set->cmds, set->ingame);
-	    gametic++;
+            gametic++;
 
-	    // modify command for duplicated tics
+            // modify command for duplicated tics
 
             TicdupSquash(set);
-	}
+        }
 
-	NetUpdate ();	// check for new console commands
+        NetUpdate(); // check for new console commands
     }
 
     // killough 3/16/98: change consoleplayer to displayplayer
