@@ -22,13 +22,13 @@
 #include "SDL.h"
 
 #include "doomstat.h"
+#include "g_game.h"
+#include "i_glob.h"
 #include "i_printf.h"
 #include "m_array.h"
-#include "m_misc.h"
-#include "g_game.h"
 #include "m_io.h"
+#include "m_config.h"
 #include "w_wad.h"
-#include "i_glob.h"
 
 //
 // I_Quit
@@ -56,8 +56,8 @@ void I_Quit(void)
         glob_t *glob;
         const char *filename;
 
-        glob = I_StartMultiGlob(tempdirs[i], GLOB_FLAG_NOCASE|GLOB_FLAG_SORTED,
-                                "*.*", NULL);
+        glob = I_StartMultiGlob(
+            tempdirs[i], GLOB_FLAG_NOCASE | GLOB_FLAG_SORTED, "*.*", NULL);
         for (;;)
         {
             filename = I_NextGlob(glob);
