@@ -162,6 +162,15 @@ enum {
 
 extern int comp[COMP_TOTAL], default_comp[COMP_TOTAL];
 
+typedef enum
+{
+  INVUL_VANILLA,
+  INVUL_MBF,
+  INVUL_GRAY,
+} invul_mode_t;
+
+extern invul_mode_t invul_mode;
+
 // -------------------------------------------
 // Language.
 extern  Language_t   language;
@@ -310,6 +319,7 @@ extern  int       playback_skiptics;
 extern  boolean   frozen_mode;
 
 extern  boolean   strictmode, default_strictmode;
+extern  boolean   force_strictmode;
 
 #define STRICTMODE(x) (strictmode ? 0 : (x))
 
