@@ -35,7 +35,7 @@
 #include "i_video.h" // fps
 #include "m_fixed.h"
 #include "m_input.h"
-#include "m_misc2.h"
+#include "m_misc.h"
 #include "m_swap.h"
 #include "p_map.h" // crosshair (linetarget)
 #include "p_mobj.h"
@@ -164,13 +164,14 @@ static hu_widget_t doom_widgets[MAX_HUDS][MAX_WIDGETS_D] = {
 
 static hu_widget_t boom_widgets[MAX_HUDS][MAX_WIDGETS_B] = {
   {
+    {&w_rate,   align_left,  align_top},
     {&w_monsec, align_left,  align_top},
     {&w_sttime, align_left,  align_top},
     {&w_coord,  align_right, align_top},
     {&w_fps,    align_right, align_top},
-    {&w_rate,   align_left,  align_top},
     {NULL}
   }, {
+    {&w_rate,   align_left,  align_top},
     {&w_armor,  align_left,  align_bottom},
     {&w_health, align_left,  align_bottom},
     {&w_ammo,   align_left,  align_bottom},
@@ -181,9 +182,9 @@ static hu_widget_t boom_widgets[MAX_HUDS][MAX_WIDGETS_B] = {
     {&w_sttime, align_left,  align_bottom},
     {&w_coord,  align_right, align_top},
     {&w_fps,    align_right, align_top},
-    {&w_rate,   align_left,  align_top},
     {NULL}
   }, {
+    {&w_rate,   align_left,  align_top},
     {&w_health, align_right, align_top},
     {&w_armor,  align_right, align_top},
     {&w_ammo,   align_right, align_bottom},
@@ -194,7 +195,6 @@ static hu_widget_t boom_widgets[MAX_HUDS][MAX_WIDGETS_B] = {
     {&w_sttime, align_left,  align_bottom},
     {&w_coord , align_right, align_top},
     {&w_fps,    align_right, align_top},
-    {&w_rate,   align_left,  align_top},
     {NULL}
   }
 };
@@ -671,6 +671,8 @@ void HU_Start(void)
   HUlib_init_multiline(&w_rate, (voxels_rendering ? 2 : 1),
                        &boom_font, colrngs[hudcolor_xyco],
                        NULL, HU_widget_build_rate);
+  // [FG] draw the IDRATE widget exclusively
+  w_rate.exclusive = true;
 
   HU_set_centered_message(false);
 
@@ -1576,8 +1578,6 @@ void HU_Erase(void)
 static boolean bsdown; // Is backspace down?
 static int bscounter;
 
-int M_StringWidth(char *string);
-
 void HU_Ticker(void)
 {
   doom_widget = doom_widgets[hud_active];
@@ -2146,7 +2146,7 @@ static boolean HU_AddHUDAlignment (char *name, int hud, char *alignstr)
 
 static void HU_ParseHUD (void)
 {
-  u_scanner_t scanner, *s;
+  u_scanner_t *s;
   int hud = -1;
   int lumpnum;
   const char *data;
@@ -2160,8 +2160,7 @@ static void HU_ParseHUD (void)
   data = W_CacheLumpNum(lumpnum, PU_CACHE);
   length = W_LumpLength(lumpnum);
 
-  scanner = U_ScanOpen(data, length, "WOOFHUD");
-  s = &scanner;
+  s = U_ScanOpen(data, length, "WOOFHUD");
 
   while (U_HasTokensLeft(s))
   {
