@@ -25,18 +25,18 @@
 #include "doomtype.h"
 #include "i_glob.h"
 #include "m_io.h"
-#include "m_misc2.h"
+#include "m_misc.h"
 
 #if defined(_MSC_VER)
 // For Visual C++, we need to include the win_opendir module.
-#include "win_opendir.h"
+#  include "win_opendir.h"
 #elif defined(HAVE_DIRENT_H)
-#include <dirent.h>
+#  include <dirent.h>
 #elif defined(__WATCOMC__)
 // Watcom has the same API in a different header.
-#include <direct.h>
+#  include <direct.h>
 #else
-#define NO_DIRENT_IMPLEMENTATION
+#  define NO_DIRENT_IMPLEMENTATION
 #endif
 
 #ifndef NO_DIRENT_IMPLEMENTATION
@@ -47,13 +47,13 @@
 // not all systems.
 static boolean IsDirectory(char *dir, struct dirent *de)
 {
-#if defined(_DIRENT_HAVE_D_TYPE)
+#  if defined(_DIRENT_HAVE_D_TYPE)
     if (de->d_type != DT_UNKNOWN && de->d_type != DT_LNK)
     {
         return de->d_type == DT_DIR;
     }
     else
-#endif
+#  endif
     {
         char *filename;
         struct stat sb;
@@ -96,8 +96,8 @@ static void FreeStringList(char **globs, int num_globs)
     free(globs);
 }
 
-glob_t *I_StartMultiGlob(const char *directory, int flags,
-                         const char *glob, ...)
+glob_t *I_StartMultiGlob(const char *directory, int flags, const char *glob,
+                         ...)
 {
     char **globs;
     int num_globs;
@@ -181,7 +181,7 @@ void I_EndGlob(glob_t *glob)
 
     free(glob->directory);
     free(glob->last_filename);
-    (void) closedir(glob->dir);
+    (void)closedir(glob->dir);
     free(glob);
 }
 
@@ -257,7 +257,7 @@ static char *NextGlob(glob_t *glob)
             return NULL;
         }
     } while (IsDirectory(glob->directory, de)
-          || !MatchesAnyGlob(de->d_name, glob));
+             || !MatchesAnyGlob(de->d_name, glob));
 
     // Return the fully-qualified path, not just the bare filename.
     temp = M_StringJoin(glob->directory, DIR_SEPARATOR_S, de->d_name, NULL);
@@ -302,7 +302,7 @@ static void SortFilenames(char **filenames, int len, int flags)
     }
     pivot = filenames[len - 1];
     left_len = 0;
-    for (i = 0; i < len-1; ++i)
+    for (i = 0; i < len - 1; ++i)
     {
         if ((flags & GLOB_FLAG_NOCASE) != 0)
         {
@@ -364,7 +364,7 @@ const char *I_NextGlob(glob_t *glob)
 
 #else /* #ifdef NO_DIRENT_IMPLEMENTATION */
 
-#warning No native implementation of file globbing.
+#  warning No native implementation of file globbing.
 
 glob_t *I_StartGlob(const char *directory, const char *glob, int flags)
 {
@@ -381,4 +381,3 @@ const char *I_NextGlob(glob_t *glob)
 }
 
 #endif /* #ifdef NO_DIRENT_IMPLEMENTATION */
-
