@@ -14,30 +14,25 @@
 // DESCRIPTION:
 //
 
-#include "i_oalmusic.h"
-#include "i_oalstream.h"
-
-#include <stdlib.h>
-#include <string.h>
-
 #include "SDL.h"
+#include "al.h"
+#include "alc.h"
 #include "alext.h"
 
+#include <stdlib.h>
+
 #include "doomtype.h"
+#include "i_oalstream.h"
 #include "i_printf.h"
-#include "i_sndfile.h"
 #include "i_sound.h"
 
 // Define the number of buffers and buffer size (in milliseconds) to use. 4
 // buffers with 4096 samples each gives a nice per-chunk size, and lets the
 // queue last for about half second at 44.1khz.
-#define NUM_BUFFERS 4
+#define NUM_BUFFERS    4
 #define BUFFER_SAMPLES 4096
 
-extern stream_module_t stream_snd_module;
-extern stream_module_t stream_xmp_module;
-
-stream_module_t *stream_modules[] =
+static stream_module_t *stream_modules[] =
 {
     &stream_snd_module,
 #if defined(HAVE_LIBXMP)
@@ -67,10 +62,10 @@ static stream_player_t player;
 static SDL_Thread *player_thread_handle;
 static int player_thread_running;
 
-static callback_func_t callback;
-
 static boolean music_initialized;
 
+static SDL_mutex *music_lock;
+
 static boolean UpdatePlayer(void)
 {
     ALint processed, state;
@@ -96,14 +91,7 @@ static boolean UpdatePlayer(void)
 
         // Read the next chunk of data, refill the buffer, and queue it back on
         // the source.
-        if (callback)
-        {
-            frames = callback(player.data, BUFFER_SAMPLES);
-        }
-        else
-        {
-            frames = active_module->I_FillStream(player.data, BUFFER_SAMPLES);
-        }
+        frames = active_module->I_FillStream(player.data, BUFFER_SAMPLES);
 
         if (frames > 0)
         {
@@ -151,10 +139,7 @@ static boolean StartPlayer(void)
     alSourceRewind(player.source);
     alSourcei(player.source, AL_BUFFER, 0);
 
-    if (!callback)
-    {
-        active_module->I_PlayStream(player.looping);
-    }
+    active_module->I_PlayStream(player.looping);
 
     // Fill the buffer queue
     for (i = 0; i < NUM_BUFFERS; i++)
@@ -163,22 +148,17 @@ static boolean StartPlayer(void)
         ALsizei size;
 
         // Get some data to give it to the buffer
-        if (callback)
-        {
-            frames = callback(player.data, BUFFER_SAMPLES);
-        }
-        else
-        {
-            frames = active_module->I_FillStream(player.data, BUFFER_SAMPLES);
-        }
+        frames = active_module->I_FillStream(player.data, BUFFER_SAMPLES);
 
         if (frames < 1)
+        {
             break;
+        }
 
         size = frames * player.frame_size;
 
         alBufferData(player.buffers[i], player.format, player.data, size,
-                    player.freq);
+                     player.freq);
     }
     if (alGetError() != AL_NO_ERROR)
     {
@@ -197,8 +177,24 @@ static int PlayerThread(void *unused)
 
     StartPlayer();
 
-    while (player_thread_running && UpdatePlayer())
+    while (true)
     {
+        boolean keep_going;
+
+        if (!UpdatePlayer())
+        {
+            break;
+        }
+
+        SDL_LockMutex(music_lock);
+        keep_going = player_thread_running;
+        SDL_UnlockMutex(music_lock);
+
+        if (!keep_going)
+        {
+            break;
+        }
+
         SDL_Delay(1);
     }
 
@@ -208,7 +204,9 @@ static int PlayerThread(void *unused)
 static boolean I_OAL_InitMusic(int device)
 {
     if (alcGetCurrentContext() == NULL)
+    {
         return false;
+    }
 
     active_module = &stream_snd_module;
 
@@ -235,23 +233,48 @@ static boolean I_OAL_InitMusic(int device)
         alSourcei(player.source, AL_SOURCE_SPATIALIZE_SOFT, AL_FALSE);
     }
 
+    for (int i = 0; i < arrlen(stream_modules); ++i)
+    {
+        stream_modules[i]->I_InitStream(0);
+    }
+
     music_initialized = true;
 
     return true;
 }
 
+int mus_gain = 100;
+int opl_gain = 200;
+
 static void I_OAL_SetMusicVolume(int volume)
 {
     if (!music_initialized)
+    {
         return;
+    }
 
-    alSourcef(player.source, AL_GAIN, (ALfloat)volume / 15.0f);
+    ALfloat gain = (ALfloat)volume / 15.0f;
+
+    if (active_module == &stream_opl_module)
+    {
+        gain *= (ALfloat)opl_gain / 100.0f;
+    }
+#if defined(HAVE_FLUIDSYNTH)
+    else if (active_module == &stream_fl_module)
+    {
+        gain *= (ALfloat)mus_gain / 100.0f;
+    }
+#endif
+
+    alSourcef(player.source, AL_GAIN, gain);
 }
 
 static void I_OAL_PauseSong(void *handle)
 {
     if (!music_initialized)
+    {
         return;
+    }
 
     alSourcePause(player.source);
 }
@@ -259,7 +282,9 @@ static void I_OAL_PauseSong(void *handle)
 static void I_OAL_ResumeSong(void *handle)
 {
     if (!music_initialized)
+    {
         return;
+    }
 
     alSourcePlay(player.source);
 }
@@ -267,7 +292,9 @@ static void I_OAL_ResumeSong(void *handle)
 static void I_OAL_PlaySong(void *handle, boolean looping)
 {
     if (!music_initialized)
+    {
         return;
+    }
 
     player.looping = looping;
 
@@ -278,33 +305,48 @@ static void I_OAL_PlaySong(void *handle, boolean looping)
         return;
     }
 
+    music_lock = SDL_CreateMutex();
+
     player_thread_running = true;
     player_thread_handle = SDL_CreateThread(PlayerThread, NULL, NULL);
+    if (player_thread_handle == NULL)
+    {
+        I_Printf(VB_ERROR, "Error creating thread: %s", SDL_GetError());
+        player_thread_running = false;
+    }
 }
 
 static void I_OAL_StopSong(void *handle)
 {
-    if (!music_initialized)
+    if (!music_initialized || !player_thread_running)
+    {
         return;
+    }
 
     alSourceStop(player.source);
+
+    SDL_LockMutex(music_lock);
+    player_thread_running = false;
+    SDL_UnlockMutex(music_lock);
+
+    SDL_WaitThread(player_thread_handle, NULL);
+
+    if (alGetError() != AL_NO_ERROR)
+    {
+        I_Printf(VB_ERROR, "I_OAL_StopSong: Error stopping playback.");
+    }
+
+    SDL_DestroyMutex(music_lock);
 }
 
 static void I_OAL_UnRegisterSong(void *handle)
 {
     if (!music_initialized)
+    {
         return;
-
-    if (player_thread_running)
-    {
-        player_thread_running = false;
-        SDL_WaitThread(player_thread_handle, NULL);
     }
 
-    if (!callback)
-    {
-        active_module->I_CloseStream();
-    }
+    active_module->I_CloseStream();
 
     if (player.data)
     {
@@ -316,11 +358,19 @@ static void I_OAL_UnRegisterSong(void *handle)
 static void I_OAL_ShutdownMusic(void)
 {
     if (!music_initialized)
+    {
         return;
+    }
 
     I_OAL_StopSong(NULL);
     I_OAL_UnRegisterSong(NULL);
 
+    if (midi_stream_module)
+    {
+        midi_stream_module->I_ShutdownStream();
+    }
+    active_module->I_ShutdownStream();
+
     alDeleteSources(1, &player.source);
     alDeleteBuffers(NUM_BUFFERS, player.buffers);
     if (alGetError() != AL_NO_ERROR)
@@ -340,7 +390,21 @@ static void *I_OAL_RegisterSong(void *data, int len)
     int i;
 
     if (!music_initialized)
+    {
         return NULL;
+    }
+
+    if (IsMid(data, len) || IsMus(data, len))
+    {
+        if (midi_stream_module
+            && midi_stream_module->I_OpenStream(data, len, &player.format,
+                                                &player.freq, &player.frame_size))
+        {
+            active_module = midi_stream_module;
+            return (void *)1;
+        }
+        return NULL;
+    }
 
     for (i = 0; i < arrlen(stream_modules); ++i)
     {
@@ -355,44 +419,14 @@ static void *I_OAL_RegisterSong(void *data, int len)
     return NULL;
 }
 
-static int I_OAL_DeviceList(const char *devices[], int size, int *current_device)
+static const char **I_OAL_DeviceList(int *current_device)
 {
-    *current_device = 0;
-    return 0;
+    return NULL;
 }
 
-void I_OAL_SetGain(float gain)
+static void I_OAL_UpdateMusic(void)
 {
-    if (!music_initialized)
-        return;
-
-    alSourcef(player.source, AL_GAIN, (ALfloat)gain);
-}
-
-boolean I_OAL_HookMusic(callback_func_t callback_func)
-{
-    if (!music_initialized)
-        return false;
-
-    if (callback_func)
-    {
-        callback = callback_func;
-
-        player.format = AL_FORMAT_STEREO16;
-        player.freq = SND_SAMPLERATE;
-        player.frame_size = 2 * sizeof(short);
-
-        I_OAL_SetGain(1.0f);
-        I_OAL_PlaySong(NULL, false);
-    }
-    else
-    {
-        I_OAL_UnRegisterSong(NULL);
-
-        callback = NULL;
-    }
-
-    return true;
+    ;
 }
 
 music_module_t music_oal_module =
@@ -404,6 +438,7 @@ music_module_t music_oal_module =
     I_OAL_ResumeSong,
     I_OAL_RegisterSong,
     I_OAL_PlaySong,
+    I_OAL_UpdateMusic,
     I_OAL_StopSong,
     I_OAL_UnRegisterSong,
     I_OAL_DeviceList,
