@@ -34,27 +34,27 @@
 #include "w_wad.h"
 #include "z_zone.h"
 
-#define OAL_ROLLOFF_FACTOR 1
-#define OAL_SPEED_OF_SOUND 343.3f
+#define OAL_ROLLOFF_FACTOR      1
+#define OAL_SPEED_OF_SOUND      343.3f
 // 128 map units per 3 meters (https://doomwiki.org/wiki/Map_unit).
 #define OAL_MAP_UNITS_PER_METER (128.0f / 3.0f)
-#define OAL_SOURCE_RADIUS 32.0f
-#define OAL_DEFAULT_PITCH 1.0f
-#define OAL_NUM_ATTRIBS 5
+#define OAL_SOURCE_RADIUS       32.0f
+#define OAL_DEFAULT_PITCH       1.0f
+#define OAL_NUM_ATTRIBS         5
 
-#define DMXHDRSIZE 8
-#define DMXPADSIZE 16
+#define DMXHDRSIZE              8
+#define DMXPADSIZE              16
 
-#define VOL_TO_GAIN(x) ((ALfloat)(x) / 127)
+#define VOL_TO_GAIN(x)          ((ALfloat)(x) / 127)
 
 // C doesn't allow casting between function and non-function pointer types, so
 // with C99 we need to use a union to reinterpret the pointer type. Pre-C99
 // still needs to use a normal cast and live with the warning (C++ is fine with
 // a regular reinterpret_cast).
 #if __STDC_VERSION__ >= 199901L
-#define FUNCTION_CAST(T, ptr) (union{void *p; T f;}){ptr}.f
+#  define FUNCTION_CAST(T, ptr) (union{void *p; T f;}){ptr}.f
 #else
-#define FUNCTION_CAST(T, ptr) (T)(ptr)
+#  define FUNCTION_CAST(T, ptr) (T)(ptr)
 #endif
 
 int snd_resampler;
@@ -64,9 +64,7 @@ int snd_doppler;
 
 boolean oal_use_doppler;
 
-static const char *oal_resamplers[] = {
-    "Nearest", "Linear", "Cubic"
-};
+static const char *oal_resamplers[] = {"Nearest", "Linear", "Cubic"};
 
 typedef struct oal_system_s
 {
@@ -120,10 +118,10 @@ static void InitDeferred(void)
 
     if (alIsExtensionPresent("AL_SOFT_deferred_updates") == AL_TRUE)
     {
-        alDeferUpdatesSOFT = FUNCTION_CAST(LPALDEFERUPDATESSOFT,
-                                           alGetProcAddress("alDeferUpdatesSOFT"));
-        alProcessUpdatesSOFT = FUNCTION_CAST(LPALPROCESSUPDATESSOFT,
-                                             alGetProcAddress("alProcessUpdatesSOFT"));
+        alDeferUpdatesSOFT = FUNCTION_CAST(
+            LPALDEFERUPDATESSOFT, alGetProcAddress("alDeferUpdatesSOFT"));
+        alProcessUpdatesSOFT = FUNCTION_CAST(
+            LPALPROCESSUPDATESSOFT, alGetProcAddress("alProcessUpdatesSOFT"));
 
         if (alDeferUpdatesSOFT && alProcessUpdatesSOFT)
         {
@@ -131,8 +129,10 @@ static void InitDeferred(void)
         }
     }
 
-    alDeferUpdatesSOFT = FUNCTION_CAST(LPALDEFERUPDATESSOFT, &wrap_DeferUpdatesSOFT);
-    alProcessUpdatesSOFT = FUNCTION_CAST(LPALPROCESSUPDATESSOFT, &wrap_ProcessUpdatesSOFT);
+    alDeferUpdatesSOFT =
+        FUNCTION_CAST(LPALDEFERUPDATESSOFT, &wrap_DeferUpdatesSOFT);
+    alProcessUpdatesSOFT =
+        FUNCTION_CAST(LPALPROCESSUPDATESSOFT, &wrap_ProcessUpdatesSOFT);
 }
 
 void I_OAL_ShutdownModule(void)
@@ -208,8 +208,8 @@ static void SetResampler(ALuint *sources)
         return;
     }
 
-    alGetStringiSOFT = FUNCTION_CAST(LPALGETSTRINGISOFT,
-                                     alGetProcAddress("alGetStringiSOFT"));
+    alGetStringiSOFT =
+        FUNCTION_CAST(LPALGETSTRINGISOFT, alGetProcAddress("alGetStringiSOFT"));
 
     if (!alGetStringiSOFT)
     {
@@ -228,7 +228,8 @@ static void SetResampler(ALuint *sources)
 
     for (i = 0; i < num_resamplers; i++)
     {
-        if (!strcasecmp(resampler_name, alGetStringiSOFT(AL_RESAMPLER_NAME_SOFT, i)))
+        if (!strcasecmp(resampler_name,
+                        alGetStringiSOFT(AL_RESAMPLER_NAME_SOFT, i)))
         {
             def_resampler = i;
             break;
@@ -236,7 +237,8 @@ static void SetResampler(ALuint *sources)
     }
     if (i == num_resamplers)
     {
-        I_Printf(VB_WARNING, " Failed to find resampler: '%s'.", resampler_name);
+        I_Printf(VB_WARNING, " Failed to find resampler: '%s'.",
+                 resampler_name);
         return;
     }
 
@@ -246,7 +248,7 @@ static void SetResampler(ALuint *sources)
     }
 
     I_Printf(VB_DEBUG, " Using '%s' resampler.",
-           alGetStringiSOFT(AL_RESAMPLER_NAME_SOFT, def_resampler));
+             alGetStringiSOFT(AL_RESAMPLER_NAME_SOFT, def_resampler));
 }
 
 void I_OAL_ResetSource2D(int channel)
@@ -282,7 +284,8 @@ void I_OAL_ResetSource3D(int channel, boolean point_source)
 
     if (oal->EXT_EFX)
     {
-        alSourcef(oal->sources[channel], AL_AIR_ABSORPTION_FACTOR, oal->absorption);
+        alSourcef(oal->sources[channel], AL_AIR_ABSORPTION_FACTOR,
+                  oal->absorption);
     }
 
     if (oal->EXT_SOURCE_RADIUS)
@@ -307,7 +310,8 @@ void I_OAL_UpdateSourceParams(int channel, const ALfloat *position,
     alSourcefv(oal->sources[channel], AL_VELOCITY, velocity);
 }
 
-void I_OAL_UpdateListenerParams(const ALfloat *position, const ALfloat *velocity,
+void I_OAL_UpdateListenerParams(const ALfloat *position,
+                                const ALfloat *velocity,
                                 const ALfloat *orientation)
 {
     if (!oal)
@@ -349,7 +353,8 @@ static void ResetParams(void)
         I_OAL_ResetSource2D(i);
         alSource3i(oal->sources[i], AL_DIRECTION, 0, 0, 0);
         alSourcei(oal->sources[i], AL_MAX_DISTANCE, S_ATTENUATOR);
-        alSourcei(oal->sources[i], AL_REFERENCE_DISTANCE, S_CLOSE_DIST >> FRACBITS);
+        alSourcei(oal->sources[i], AL_REFERENCE_DISTANCE,
+                  S_CLOSE_DIST >> FRACBITS);
     }
     // Spatialization is required even for 2D panning emulation.
     if (oal->SOFT_source_spatialize)
@@ -382,9 +387,13 @@ static void PrintDeviceInfo(ALCdevice *device)
     ALCint srate = -1;
 
     if (alcIsExtensionPresent(device, "ALC_ENUMERATE_ALL_EXT") == ALC_TRUE)
+    {
         name = alcGetString(device, ALC_ALL_DEVICES_SPECIFIER);
+    }
     else
+    {
         name = alcGetString(device, ALC_DEVICE_SPECIFIER);
+    }
 
     alcGetIntegerv(device, ALC_FREQUENCY, 1, &srate);
     I_Printf(VB_INFO, " Using '%s' @ %d Hz.", name, srate);
@@ -407,8 +416,8 @@ static void GetAttribs(ALCint *attribs)
     if (alcIsExtensionPresent(oal->device, "ALC_SOFT_output_mode") == ALC_TRUE)
     {
         attribs[i++] = ALC_OUTPUT_MODE_SOFT;
-        attribs[i++] = use_3d ? (snd_hrtf ? ALC_STEREO_HRTF_SOFT : ALC_ANY_SOFT) :
-                                ALC_STEREO_BASIC_SOFT;
+        attribs[i++] = use_3d ? (snd_hrtf ? ALC_STEREO_HRTF_SOFT : ALC_ANY_SOFT)
+                              : ALC_STEREO_BASIC_SOFT;
     }
 #endif
 }
@@ -452,9 +461,12 @@ boolean I_OAL_InitSound(void)
         return false;
     }
 
-    oal->SOFT_source_spatialize = (alIsExtensionPresent("AL_SOFT_source_spatialize") == AL_TRUE);
-    oal->EXT_EFX = (alcIsExtensionPresent(oal->device, "ALC_EXT_EFX") == ALC_TRUE);
-    oal->EXT_SOURCE_RADIUS = (alIsExtensionPresent("AL_EXT_SOURCE_RADIUS") == AL_TRUE);
+    oal->SOFT_source_spatialize =
+        (alIsExtensionPresent("AL_SOFT_source_spatialize") == AL_TRUE);
+    oal->EXT_EFX =
+        (alcIsExtensionPresent(oal->device, "ALC_EXT_EFX") == ALC_TRUE);
+    oal->EXT_SOURCE_RADIUS =
+        (alIsExtensionPresent("AL_EXT_SOURCE_RADIUS") == AL_TRUE);
     InitDeferred();
     ResetParams();
 
@@ -594,9 +606,9 @@ boolean I_OAL_CacheSound(sfxinfo_t *sfx)
         // Check the header, and ensure this is a valid sound
         if (lumplen > DMXHDRSIZE && lumpdata[0] == 0x03 && lumpdata[1] == 0x00)
         {
-            freq = (lumpdata[3] <<  8) |  lumpdata[2];
-            size = (lumpdata[7] << 24) | (lumpdata[6] << 16) |
-                   (lumpdata[5] <<  8) |  lumpdata[4];
+            freq = (lumpdata[3] << 8) | lumpdata[2];
+            size = (lumpdata[7] << 24) | (lumpdata[6] << 16)
+                   | (lumpdata[5] << 8) | lumpdata[4];
 
             // Don't play sounds that think they're longer than they really are,
             // only contain padding, or are shorter than the padding size.
@@ -617,16 +629,19 @@ boolean I_OAL_CacheSound(sfxinfo_t *sfx)
             // All Doom sounds are 8-bit
             format = AL_FORMAT_MONO8;
 
-            // Fade in sounds that start at a non-zero amplitude to prevent clicking.
+            // Fade in sounds that start at a non-zero amplitude to prevent
+            // clicking.
             FadeInMono8(sampledata, size, freq);
         }
         else
         {
             size = lumplen;
 
-            if (I_SND_LoadFile(lumpdata, &format, &wavdata, &size, &freq) == false)
+            if (I_SND_LoadFile(lumpdata, &format, &wavdata, &size, &freq)
+                == false)
             {
-                I_Printf(VB_WARNING, " I_OAL_CacheSound: %s", lumpinfo[lumpnum].name);
+                I_Printf(VB_WARNING, " I_OAL_CacheSound: %s",
+                         lumpinfo[lumpnum].name);
                 break;
             }
 
@@ -663,8 +678,8 @@ boolean I_OAL_CacheSound(sfxinfo_t *sfx)
 
     if (sfx->cached == false)
     {
-      sfx->lumpnum = -2; // [FG] don't try again
-      return false;
+        sfx->lumpnum = -2; // [FG] don't try again
+        return false;
     }
 
     return true;
@@ -741,5 +756,6 @@ void I_OAL_SetPan(int channel, int separation)
     // the circular shape of the sound field along the z-axis. The end result
     // is perceived to move in a straight line along the x-axis only (panning).
     pan = (ALfloat)separation / 255.0f - 0.5f;
-    alSource3f(oal->sources[channel], AL_POSITION, pan, 0.0f, -sqrtf(1.0f - pan * pan));
+    alSource3f(oal->sources[channel], AL_POSITION, pan, 0.0f,
+               -sqrtf(1.0f - pan * pan));
 }
