@@ -26,7 +26,7 @@
 #include "i_system.h"
 #include "i_timer.h"
 #include "m_argv.h"
-#include "m_misc2.h"
+#include "m_misc.h"
 #include "net_client.h"
 #include "net_common.h"
 #include "net_io.h"
@@ -36,7 +36,7 @@
 #include "net_structrw.h"
 
 // How often to refresh our registration with the master server.
-#define MASTER_REFRESH_PERIOD 30  /* twice per minute */
+#define MASTER_REFRESH_PERIOD 30 /* twice per minute */
 
 // How often to re-resolve the address of the master server?
 #define MASTER_RESOLVE_PERIOD 8 * 60 * 60 /* 8 hours */
@@ -120,7 +120,7 @@ typedef struct
 
 // structure used for the recv window
 
-typedef struct 
+typedef struct
 {
     // Whether this tic has been received yet
 
@@ -171,16 +171,18 @@ static void NET_SV_DisconnectClient(net_client_t *client)
 
 static boolean ClientConnected(net_client_t *client)
 {
-    // Check that the client is properly connected: ie. not in the 
+    // Check that the client is properly connected: ie. not in the
     // process of connecting or disconnecting
 
-    return client->active 
-        && client->connection.state == NET_CONN_STATE_CONNECTED;
+    return client->active
+           && client->connection.state == NET_CONN_STATE_CONNECTED;
 }
 
 // Send a message to be displayed on a client's console
 
-static void NET_SV_SendConsoleMessage(net_client_t *client, const char *s, ...) PRINTF_ATTR(2, 3);
+static void NET_SV_SendConsoleMessage(net_client_t *client, const char *s, ...)
+    PRINTF_ATTR(2, 3);
+
 static void NET_SV_SendConsoleMessage(net_client_t *client, const char *s, ...)
 {
     char buf[1024];
@@ -190,8 +192,8 @@ static void NET_SV_SendConsoleMessage(net_client_t *client, const char *s, ...)
     va_start(args, s);
     M_vsnprintf(buf, sizeof(buf), s, args);
     va_end(args);
-    
-    packet = NET_Conn_NewReliable(&client->connection, 
+
+    packet = NET_Conn_NewReliable(&client->connection,
                                   NET_PACKET_TYPE_CONSOLE_MESSAGE);
 
     NET_WriteString(packet, buf);
@@ -200,6 +202,7 @@ static void NET_SV_SendConsoleMessage(net_client_t *client, const char *s, ...)
 // Send a message to all clients
 
 static void NET_SV_BroadcastMessage(const char *s, ...) PRINTF_ATTR(1, 2);
+
 static void NET_SV_BroadcastMessage(const char *s, ...)
 {
     char buf[1024];
@@ -210,7 +213,7 @@ static void NET_SV_BroadcastMessage(const char *s, ...)
     M_vsnprintf(buf, sizeof(buf), s, args);
     va_end(args);
 
-    for (i=0; i<MAXNETNODES; ++i)
+    for (i = 0; i < MAXNETNODES; ++i)
     {
         if (ClientConnected(&clients[i]))
         {
@@ -221,7 +224,6 @@ static void NET_SV_BroadcastMessage(const char *s, ...)
     I_Printf(VB_INFO, "%s", buf);
 }
 
-
 // Assign player numbers to connected clients
 
 static void NET_SV_AssignPlayers(void)
@@ -231,7 +233,7 @@ static void NET_SV_AssignPlayers(void)
 
     pl = 0;
 
-    for (i=0; i<MAXNETNODES; ++i)
+    for (i = 0; i < MAXNETNODES; ++i)
     {
         if (ClientConnected(&clients[i]))
         {
@@ -248,7 +250,7 @@ static void NET_SV_AssignPlayers(void)
         }
     }
 
-    for (; pl<NET_MAXPLAYERS; ++pl)
+    for (; pl < NET_MAXPLAYERS; ++pl)
     {
         sv_players[pl] = NULL;
     }
@@ -263,7 +265,7 @@ static int NET_SV_NumPlayers(void)
 
     result = 0;
 
-    for (i=0; i<NET_MAXPLAYERS; ++i)
+    for (i = 0; i < NET_MAXPLAYERS; ++i)
     {
         if (sv_players[i] != NULL && ClientConnected(sv_players[i]))
         {
@@ -283,8 +285,8 @@ static int NET_SV_NumReadyPlayers(void)
 
     for (i = 0; i < MAXNETNODES; ++i)
     {
-        if (ClientConnected(&clients[i])
-         && !clients[i].drone && clients[i].ready)
+        if (ClientConnected(&clients[i]) && !clients[i].drone
+            && clients[i].ready)
         {
             ++result;
         }
@@ -319,7 +321,7 @@ static int NET_SV_NumDrones(void)
 
     result = 0;
 
-    for (i=0; i<MAXNETNODES; ++i)
+    for (i = 0; i < MAXNETNODES; ++i)
     {
         if (ClientConnected(&clients[i]) && clients[i].drone)
         {
@@ -339,7 +341,7 @@ static int NET_SV_NumClients(void)
 
     count = 0;
 
-    for (i=0; i<MAXNETNODES; ++i)
+    for (i = 0; i < MAXNETNODES; ++i)
     {
         if (ClientConnected(&clients[i]))
         {
@@ -361,7 +363,7 @@ static net_client_t *NET_SV_Controller(void)
 
     best = NULL;
 
-    for (i=0; i<MAXNETNODES; ++i)
+    for (i = 0; i < MAXNETNODES; ++i)
     {
         // Can't be controller?
 
@@ -416,12 +418,10 @@ static void NET_SV_SendWaitingData(net_client_t *client)
 
     for (i = 0; i < wait_data.num_players; ++i)
     {
-        M_StringCopy(wait_data.player_names[i],
-                     sv_players[i]->name,
+        M_StringCopy(wait_data.player_names[i], sv_players[i]->name,
                      MAXPLAYERNAME);
         M_StringCopy(wait_data.player_addrs[i],
-                     NET_AddrToString(sv_players[i]->addr),
-                     MAXPLAYERNAME);
+                     NET_AddrToString(sv_players[i]->addr), MAXPLAYERNAME);
     }
 
     // Construct packet:
@@ -444,7 +444,7 @@ static unsigned int NET_SV_LatestAcknowledged(void)
     unsigned int lowtic = UINT_MAX;
     int i;
 
-    for (i=0; i<MAXNETNODES; ++i) 
+    for (i = 0; i < MAXNETNODES; ++i)
     {
         if (ClientConnected(&clients[i]))
         {
@@ -458,7 +458,6 @@ static unsigned int NET_SV_LatestAcknowledged(void)
     return lowtic;
 }
 
-
 // Possibly advance the recv window if all connected clients have
 // used the data in the window
 
@@ -482,10 +481,10 @@ static void NET_SV_AdvanceWindow(void)
 
         // Check we have tics from all players for first tic in
         // the recv window
-        
+
         should_advance = true;
 
-        for (i=0; i<NET_MAXPLAYERS; ++i)
+        for (i = 0; i < NET_MAXPLAYERS; ++i)
         {
             if (sv_players[i] == NULL || !ClientConnected(sv_players[i]))
             {
@@ -501,18 +500,18 @@ static void NET_SV_AdvanceWindow(void)
 
         if (!should_advance)
         {
-            // The first tic is not complete: ie. we have not 
+            // The first tic is not complete: ie. we have not
             // received tics from all connected players.  This can
             // happen if only one player is in the game.
 
             break;
         }
-        
+
         // Advance the window
 
         memmove(recvwindow, recvwindow + 1,
                 sizeof(*recvwindow) * (BACKUPTICS - 1));
-        memset(&recvwindow[BACKUPTICS-1], 0, sizeof(*recvwindow));
+        memset(&recvwindow[BACKUPTICS - 1], 0, sizeof(*recvwindow));
         ++recvwindow_start;
         NET_Log("server: advanced receive window to %d", recvwindow_start);
     }
@@ -524,7 +523,7 @@ static net_client_t *NET_SV_FindClient(net_addr_t *addr)
 {
     int i;
 
-    for (i=0; i<MAXNETNODES; ++i) 
+    for (i = 0; i < MAXNETNODES; ++i)
     {
         if (clients[i].active && clients[i].addr == addr)
         {
@@ -606,7 +605,8 @@ static void NET_SV_ParseSYN(net_packet_t *packet, net_client_t *client,
 
         case NET_OLD_MAGIC_NUMBER:
             NET_Log("server: error: client using old magic number: %d", magic);
-            NET_SV_SendReject(addr,
+            NET_SV_SendReject(
+                addr,
                 "You are using an old client version that is not supported by "
                 "this server. This server is running " PROJECT_STRING ".");
             return;
@@ -635,9 +635,10 @@ static void NET_SV_ParseSYN(net_packet_t *packet, net_client_t *client,
         char reject_msg[256];
 
         M_snprintf(reject_msg, sizeof(reject_msg),
-            "Version mismatch: server version is: " PROJECT_STRING "; "
-            "client is: %s. No common compatible protocol could be "
-            "negotiated.", client_version);
+                   "Version mismatch: server version is: " PROJECT_STRING "; "
+                   "client is: %s. No common compatible protocol could be "
+                   "negotiated.",
+                   client_version);
         NET_SV_SendReject(addr, reject_msg);
         NET_Log("server: error: no common protocol");
         return;
@@ -651,8 +652,8 @@ static void NET_SV_ParseSYN(net_packet_t *packet, net_client_t *client,
         return;
     }
 
-    if (/*!D_ValidGameMode(data.gamemission, data.gamemode)
-     ||*/ data.max_players > NET_MAXPLAYERS)
+    if (/*!D_ValidGameMode(data.gamemission, data.gamemode) ||*/
+        data.max_players > NET_MAXPLAYERS)
     {
         NET_Log("server: error: invalid connect data, max_players=%d, "
                 "gamemission=%d, gamemode=%d",
@@ -685,10 +686,10 @@ static void NET_SV_ParseSYN(net_packet_t *packet, net_client_t *client,
     num_players = NET_SV_NumPlayers();
 
     if ((!data.drone && num_players >= NET_SV_MaxPlayers())
-     || NET_SV_NumClients() >= MAXNETNODES)
+        || NET_SV_NumClients() >= MAXNETNODES)
     {
-        NET_Log("server: no more players, num_players=%d, max=%d",
-                num_players, NET_SV_MaxPlayers());
+        NET_Log("server: no more players, num_players=%d, max=%d", num_players,
+                NET_SV_MaxPlayers());
         NET_SV_SendReject(addr, "Server is full!");
         return;
     }
@@ -702,8 +703,8 @@ static void NET_SV_ParseSYN(net_packet_t *packet, net_client_t *client,
     {
         sv_gamemode = data.gamemode;
         sv_gamemission = data.gamemission;
-        NET_Log("server: new game, mode=%d, mission=%d",
-                sv_gamemode, sv_gamemission);
+        NET_Log("server: new game, mode=%d, mission=%d", sv_gamemode,
+                sv_gamemission);
     }
 
     // Check the connecting client is playing the same game as all
@@ -713,20 +714,18 @@ static void NET_SV_ParseSYN(net_packet_t *packet, net_client_t *client,
         char msg[128];
         NET_Log("server: wrong mode/mission, %d != %d || %d != %d",
                 data.gamemode, sv_gamemode, data.gamemission, sv_gamemission);
-/*
+        /*
         M_snprintf(msg, sizeof(msg),
                    "Game mismatch: server is %s (%s), client is %s (%s)",
                    D_GameMissionString(sv_gamemission),
                    D_GameModeString(sv_gamemode),
                    D_GameMissionString(data.gamemission),
                    D_GameModeString(data.gamemode));
-*/
+        */
         M_snprintf(msg, sizeof(msg),
-                  "Game mismatch: server is %d (%d), client is %d (%d)",
-                  sv_gamemission,
-                  sv_gamemode,
-                  data.gamemission,
-                  data.gamemode);
+                   "Game mismatch: server is %d (%d), client is %d (%d)",
+                   sv_gamemission, sv_gamemode, data.gamemission,
+                   data.gamemode);
 
         NET_SV_SendReject(addr, msg);
         return;
@@ -737,7 +736,7 @@ static void NET_SV_ParseSYN(net_packet_t *packet, net_client_t *client,
     {
         // find a slot, or return if none found
 
-        for (i=0; i<MAXNETNODES; ++i)
+        for (i = 0; i < MAXNETNODES; ++i)
         {
             if (!clients[i].active)
             {
@@ -805,7 +804,7 @@ static void NET_SV_ParseLaunch(net_packet_t *packet, net_client_t *client)
     if (client != NET_SV_Controller())
     {
         NET_Log("server: error: this client isn't the controller, %p != %p",
-                (void*)client, (void*)NET_SV_Controller());
+                (void *)client, (void *)NET_SV_Controller());
         return;
     }
 
@@ -823,10 +822,12 @@ static void NET_SV_ParseLaunch(net_packet_t *packet, net_client_t *client)
     NET_SV_AssignPlayers();
     num_players = NET_SV_NumPlayers();
 
-    for (i=0; i<MAXNETNODES; ++i)
+    for (i = 0; i < MAXNETNODES; ++i)
     {
         if (!ClientConnected(&clients[i]))
+        {
             continue;
+        }
 
         launchpacket = NET_Conn_NewReliable(&clients[i].connection,
                                             NET_PACKET_TYPE_LAUNCH);
@@ -887,7 +888,9 @@ static void StartGame(void)
     for (i = 0; i < MAXNETNODES; ++i)
     {
         if (!ClientConnected(&clients[i]))
+        {
             continue;
+        }
 
         clients[i].last_gamedata_time = nowtime;
 
@@ -1028,7 +1031,7 @@ static void NET_SV_SendResendRequest(net_client_t *client, int start, int end)
 
     nowtime = I_GetTimeMS();
 
-    for (i=start; i<=end; ++i)
+    for (i = start; i <= end; ++i)
     {
         index = i - recvwindow_start;
 
@@ -1038,7 +1041,7 @@ static void NET_SV_SendResendRequest(net_client_t *client, int start, int end)
 
             continue;
         }
-        
+
         recvobj = &recvwindow[index][client->player_number];
 
         recvobj->resend_time = nowtime;
@@ -1060,7 +1063,7 @@ static void NET_SV_CheckResends(net_client_t *client)
     resend_start = -1;
     resend_end = -1;
 
-    for (i=0; i<BACKUPTICS; ++i)
+    for (i = 0; i < BACKUPTICS; ++i)
     {
         net_client_recv_t *recvobj;
         boolean need_resend;
@@ -1070,9 +1073,8 @@ static void NET_SV_CheckResends(net_client_t *client)
         // if need_resend is true, this tic needs another retransmit
         // request (300ms timeout)
 
-        need_resend = !recvobj->active
-                   && recvobj->resend_time != 0
-                   && nowtime > recvobj->resend_time + 300;
+        need_resend = !recvobj->active && recvobj->resend_time != 0
+                      && nowtime > recvobj->resend_time + 300;
 
         if (need_resend)
         {
@@ -1090,9 +1092,8 @@ static void NET_SV_CheckResends(net_client_t *client)
                     NET_AddrToString(client->addr),
                     recvwindow_start + resend_start,
                     recvwindow_start + resend_end);
-                    //&recvwindow[resend_start][player].resend_time);
-            NET_SV_SendResendRequest(client, 
-                                     recvwindow_start + resend_start,
+            //&recvwindow[resend_start][player].resend_time);
+            NET_SV_SendResendRequest(client, recvwindow_start + resend_start,
                                      recvwindow_start + resend_end);
 
             resend_start = -1;
@@ -1102,12 +1103,10 @@ static void NET_SV_CheckResends(net_client_t *client)
     if (resend_start >= 0)
     {
         NET_Log("server: resend request to %s timed out for %d-%d",
-                NET_AddrToString(client->addr),
-                recvwindow_start + resend_start,
+                NET_AddrToString(client->addr), recvwindow_start + resend_start,
                 recvwindow_start + resend_end);
-                //&recvwindow[resend_start][player].resend_time);
-        NET_SV_SendResendRequest(client,
-                                 recvwindow_start + resend_start,
+        //&recvwindow[resend_start][player].resend_time);
+        NET_SV_SendResendRequest(client, recvwindow_start + resend_start,
                                  recvwindow_start + resend_end);
     }
 }
@@ -1143,16 +1142,15 @@ static void NET_SV_ParseGameData(net_packet_t *packet, net_client_t *client)
     player = client->player_number;
 
     // Read header
-    if (!NET_ReadInt8(packet, &ackseq)
-     || !NET_ReadInt8(packet, &seq)
-     || !NET_ReadInt8(packet, &num_tics))
+    if (!NET_ReadInt8(packet, &ackseq) || !NET_ReadInt8(packet, &seq)
+        || !NET_ReadInt8(packet, &num_tics))
     {
         NET_Log("server: error: failed to read header");
         return;
     }
 
-    NET_Log("server: got game data, seq=%d, num_tics=%d, ackseq=%d",
-            seq, num_tics, ackseq);
+    NET_Log("server: got game data, seq=%d, num_tics=%d, ackseq=%d", seq,
+            num_tics, ackseq);
 
     // Get the current time
     nowtime = I_GetTimeMS();
@@ -1163,13 +1161,13 @@ static void NET_SV_ParseGameData(net_packet_t *packet, net_client_t *client)
 
     // Sanity checks
 
-    for (i=0; i<num_tics; ++i)
+    for (i = 0; i < num_tics; ++i)
     {
         net_ticdiff_t diff;
         signed int latency;
 
         if (!NET_ReadSInt16(packet, &latency)
-         || !NET_ReadTiccmdDiff(packet, &diff, sv_settings.lowres_turn))
+            || !NET_ReadTiccmdDiff(packet, &diff, sv_settings.lowres_turn))
         {
             return;
         }
@@ -1189,7 +1187,8 @@ static void NET_SV_ParseGameData(net_packet_t *packet, net_client_t *client)
         recvobj->latency = latency;
 
         client->last_gamedata_time = nowtime;
-        NET_Log("server: stored tic %lu for player %d", (unsigned long)seq + i, player);
+        NET_Log("server: stored tic %lu for player %d", (unsigned long)seq + i,
+                player);
     }
 
     // Higher acknowledgement point?
@@ -1201,22 +1200,26 @@ static void NET_SV_ParseGameData(net_packet_t *packet, net_client_t *client)
     }
 
     // Has this been received out of sequence, ie. have we not received
-    // all tics before the first tic in this packet?  If so, send a 
+    // all tics before the first tic in this packet?  If so, send a
     // resend request.
 
-    //printf("SV: %p: %i\n", client, seq);
+    // printf("SV: %p: %i\n", client, seq);
 
     resend_end = seq - recvwindow_start;
 
     if (resend_end <= 0)
+    {
         return;
+    }
 
     if (resend_end >= BACKUPTICS)
+    {
         resend_end = BACKUPTICS - 1;
+    }
 
     index = resend_end - 1;
     resend_start = resend_end;
-    
+
     while (index >= 0)
     {
         recvobj = &recvwindow[index][player];
@@ -1245,8 +1248,7 @@ static void NET_SV_ParseGameData(net_packet_t *packet, net_client_t *client)
         NET_Log("server: request resend for %d-%d before %d",
                 recvwindow_start + resend_start,
                 recvwindow_start + resend_end - 1, seq);
-        NET_SV_SendResendRequest(client, 
-                                 recvwindow_start + resend_start, 
+        NET_SV_SendResendRequest(client, recvwindow_start + resend_start,
                                  recvwindow_start + resend_end - 1);
     }
 }
@@ -1285,8 +1287,8 @@ static void NET_SV_ParseGameDataACK(net_packet_t *packet, net_client_t *client)
     }
 }
 
-static void NET_SV_SendTics(net_client_t *client, 
-                            unsigned int start, unsigned int end)
+static void NET_SV_SendTics(net_client_t *client, unsigned int start,
+                            unsigned int end)
 {
     net_packet_t *packet;
     unsigned int i;
@@ -1298,11 +1300,11 @@ static void NET_SV_SendTics(net_client_t *client,
     // Send the start tic and number of tics
 
     NET_WriteInt8(packet, start & 0xff);
-    NET_WriteInt8(packet, end-start + 1);
+    NET_WriteInt8(packet, end - start + 1);
 
     // Write the tics
 
-    for (i=start; i<=end; ++i)
+    for (i = start; i <= end; ++i)
     {
         net_full_ticcmd_t *cmd;
 
@@ -1314,20 +1316,21 @@ static void NET_SV_SendTics(net_client_t *client,
         }
 
         // Add command
-       
+
         NET_WriteFullTiccmd(packet, cmd, sv_settings.lowres_turn);
     }
-    
+
     // Send packet
 
     NET_Conn_SendPacket(&client->connection, packet);
-    
+
     NET_FreePacket(packet);
 }
 
 // Parse a retransmission request from a client
 
-static void NET_SV_ParseResendRequest(net_packet_t *packet, net_client_t *client)
+static void NET_SV_ParseResendRequest(net_packet_t *packet,
+                                      net_client_t *client)
 {
     unsigned int start, last;
     unsigned int num_tics;
@@ -1337,20 +1340,19 @@ static void NET_SV_ParseResendRequest(net_packet_t *packet, net_client_t *client
 
     // Read the starting tic and number of tics
 
-    if (!NET_ReadInt32(packet, &start)
-     || !NET_ReadInt8(packet, &num_tics))
+    if (!NET_ReadInt32(packet, &start) || !NET_ReadInt8(packet, &num_tics))
     {
         NET_Log("server: error: missing fields for resend");
         return;
     }
 
-    //printf("SV: %p: resend %i-%i\n", client, start, start+num_tics-1);
+    // printf("SV: %p: resend %i-%i\n", client, start, start+num_tics-1);
 
     // Check we have all the requested tics
 
     last = start + num_tics - 1;
 
-    for (i=start; i<=last; ++i)
+    for (i = start; i <= last; ++i)
     {
         net_full_ticcmd_t *cmd;
 
@@ -1359,11 +1361,11 @@ static void NET_SV_ParseResendRequest(net_packet_t *packet, net_client_t *client
         if (i != cmd->seq)
         {
             // We do not have the requested tic (any more)
-            // This is pretty fatal.  We could disconnect the client, 
-            // but then again this could be a spoofed packet.  Just 
+            // This is pretty fatal.  We could disconnect the client,
+            // but then again this could be a spoofed packet.  Just
             // ignore it.
-            NET_Log("server: error: don't have tic %d any more, "
-                    "can't resend", i);
+            NET_Log("server: error: don't have tic %d any more, can't resend",
+                    i);
             return;
         }
     }
@@ -1531,7 +1533,7 @@ static void NET_SV_Packet(net_packet_t *packet, net_addr_t *addr)
     }
     else
     {
-        //printf("SV: %s: %i\n", NET_AddrToString(addr), packet_type);
+        // printf("SV: %s: %i\n", NET_AddrToString(addr), packet_type);
 
         switch (packet_type)
         {
@@ -1558,7 +1560,6 @@ static void NET_SV_Packet(net_packet_t *packet, net_addr_t *addr)
     }
 }
 
-
 static void NET_SV_PumpSendQueue(net_client_t *client)
 {
     net_full_ticcmd_t cmd;
@@ -1574,9 +1575,9 @@ static void NET_SV_PumpSendQueue(net_client_t *client)
     {
         return;
     }
-    
+
     // Work out the index into the receive window
-   
+
     recv_index = client->sendseq - recvwindow_start;
 
     if (recv_index < 0 || recv_index >= BACKUPTICS)
@@ -1589,7 +1590,7 @@ static void NET_SV_PumpSendQueue(net_client_t *client)
 
     num_players = 0;
 
-    for (i=0; i<NET_MAXPLAYERS; ++i)
+    for (i = 0; i < NET_MAXPLAYERS; ++i)
     {
         if (sv_players[i] == client)
         {
@@ -1626,14 +1627,14 @@ static void NET_SV_PumpSendQueue(net_client_t *client)
     }
 
     // We have all data we need to generate a command for this tic.
-    
+
     cmd.seq = client->sendseq;
 
     // Add ticcmds from all players
 
     cmd.latency = 0;
 
-    for (i=0; i<NET_MAXPLAYERS; ++i)
+    for (i = 0; i < NET_MAXPLAYERS; ++i)
     {
         net_client_recv_t *recvobj;
 
@@ -1644,7 +1645,7 @@ static void NET_SV_PumpSendQueue(net_client_t *client)
             cmd.playeringame[i] = false;
             continue;
         }
-        
+
         if (sv_players[i] == NULL || !recvwindow[recv_index][i].active)
         {
             cmd.playeringame[i] = false;
@@ -1658,10 +1659,12 @@ static void NET_SV_PumpSendQueue(net_client_t *client)
         cmd.cmds[i] = recvobj->diff;
 
         if (recvobj->latency > cmd.latency)
+        {
             cmd.latency = recvobj->latency;
+        }
     }
 
-    //printf("SV: %i: latency %i\n", client->player_number, cmd.latency);
+    // printf("SV: %i: latency %i\n", client->player_number, cmd.latency);
 
     // Add into the queue
 
@@ -1673,7 +1676,9 @@ static void NET_SV_PumpSendQueue(net_client_t *client)
     endtic = client->sendseq;
 
     if (starttic < 0)
+    {
         starttic = 0;
+    }
 
     NET_Log("server: send tics %d-%d to %s", starttic, endtic,
             NET_AddrToString(client->addr));
@@ -1684,7 +1689,7 @@ static void NET_SV_PumpSendQueue(net_client_t *client)
 
 // Prevent against deadlock: resend requests are usually only
 // triggered if we miss a packet and receive the next one.
-// If we miss a whole load of packets, we can end up in a 
+// If we miss a whole load of packets, we can end up in a
 // deadlock situation where the client will not send any more.
 // If we don't receive any game data in a while, trigger a resend
 // request for the next tic we're expecting.
@@ -1708,13 +1713,12 @@ void NET_SV_CheckDeadlock(net_client_t *client)
     if (nowtime - client->last_gamedata_time > 1000)
     {
         NET_Log("server: no gamedata from %s since %d - deadlock?",
-                NET_AddrToString(client->addr),
-                client->last_gamedata_time);
+                NET_AddrToString(client->addr), client->last_gamedata_time);
 
         // Search the receive window for the first tic we are expecting
         // from this player.
 
-        for (i=0; i<BACKUPTICS; ++i)
+        for (i = 0; i < BACKUPTICS; ++i)
         {
             if (!recvwindow[i][client->player_number].active)
             {
@@ -1723,8 +1727,7 @@ void NET_SV_CheckDeadlock(net_client_t *client)
 
                 // Found a tic we haven't received.  Send a resend request.
 
-                NET_SV_SendResendRequest(client,
-                                         recvwindow_start + i,
+                NET_SV_SendResendRequest(client, recvwindow_start + i,
                                          recvwindow_start + i + 5);
 
                 client->last_gamedata_time = nowtime;
@@ -1746,7 +1749,7 @@ void NET_SV_CheckDeadlock(net_client_t *client)
     }
 }
 
-// Called when all players have disconnected.  Return to listening for 
+// Called when all players have disconnected.  Return to listening for
 // players to start a new game, and disconnect any drones still connected.
 
 static void NET_SV_GameEnded(void)
@@ -1756,7 +1759,7 @@ static void NET_SV_GameEnded(void)
     server_state = SERVER_WAITING_LAUNCH;
     sv_gamemode = indetermined;
 
-    for (i=0; i<MAXNETNODES; ++i)
+    for (i = 0; i < MAXNETNODES; ++i)
     {
         if (clients[i].active)
         {
@@ -1774,7 +1777,7 @@ static void NET_SV_RunClient(net_client_t *client)
     NET_Conn_Run(&client->connection);
 
     if (client->connection.state == NET_CONN_STATE_DISCONNECTED
-     && client->connection.disconnect_reason == NET_DISCONNECT_TIMEOUT)
+        && client->connection.disconnect_reason == NET_DISCONNECT_TIMEOUT)
     {
         NET_Log("server: client at %s timed out",
                 NET_AddrToString(client->addr));
@@ -1805,7 +1808,7 @@ static void NET_SV_RunClient(net_client_t *client)
         // Are there any clients left connected?  If not, return the
         // server to the waiting-for-players state.
         //
-	// Disconnect any drones still connected.
+        // Disconnect any drones still connected.
 
         if (NET_SV_NumPlayers() <= 0)
         {
@@ -1827,8 +1830,8 @@ static void NET_SV_RunClient(net_client_t *client)
 
         // Send information once every second
 
-        if (client->last_send_time < 0 
-         || I_GetTimeMS() - client->last_send_time > 1000)
+        if (client->last_send_time < 0
+            || I_GetTimeMS() - client->last_send_time > 1000)
         {
             NET_SV_SendWaitingData(client);
             client->last_send_time = I_GetTimeMS();
@@ -1861,8 +1864,8 @@ void NET_SV_Init(void)
     server_context = NET_NewContext();
 
     // no clients yet
-   
-    for (i=0; i<MAXNETNODES; ++i) 
+
+    for (i = 0; i < MAXNETNODES; ++i)
     {
         clients[i].active = false;
     }
@@ -1961,7 +1964,7 @@ void NET_SV_Run(void)
     // "Run" any clients that may have things to do, independent of responses
     // to received packets
 
-    for (i=0; i<MAXNETNODES; ++i)
+    for (i = 0; i < MAXNETNODES; ++i)
     {
         if (clients[i].active)
         {
@@ -2002,12 +2005,12 @@ void NET_SV_Shutdown(void)
     {
         return;
     }
-    
+
     I_Printf(VB_WARNING, "SV: Shutting down server...");
 
     // Disconnect all clients
-    
-    for (i=0; i<MAXNETNODES; ++i)
+
+    for (i = 0; i < MAXNETNODES; ++i)
     {
         if (clients[i].active)
         {
@@ -2026,7 +2029,7 @@ void NET_SV_Shutdown(void)
 
         running = false;
 
-        for (i=0; i<MAXNETNODES; ++i)
+        for (i = 0; i < MAXNETNODES; ++i)
         {
             if (clients[i].active)
             {
@@ -2039,7 +2042,8 @@ void NET_SV_Shutdown(void)
         if (I_GetTimeMS() - start_time > 5000)
         {
             running = false;
-            I_Printf(VB_WARNING, "SV: Timed out waiting for clients to disconnect.");
+            I_Printf(VB_WARNING,
+                     "SV: Timed out waiting for clients to disconnect.");
         }
 
         // Run the client code in case this is a loopback client.
