@@ -22,19 +22,27 @@
 void NET_WriteConnectData(net_packet_t *packet, net_connect_data_t *data);
 boolean NET_ReadConnectData(net_packet_t *packet, net_connect_data_t *data);
 
-extern void NET_WriteSettings(net_packet_t *packet, net_gamesettings_t *settings);
-extern boolean NET_ReadSettings(net_packet_t *packet, net_gamesettings_t *settings);
+extern void NET_WriteSettings(net_packet_t *packet,
+                              net_gamesettings_t *settings);
+extern boolean NET_ReadSettings(net_packet_t *packet,
+                                net_gamesettings_t *settings);
 
-extern void NET_WriteQueryData(net_packet_t *packet, net_querydata_t *querydata);
-extern boolean NET_ReadQueryData(net_packet_t *packet, net_querydata_t *querydata);
+extern void NET_WriteQueryData(net_packet_t *packet,
+                               net_querydata_t *querydata);
+extern boolean NET_ReadQueryData(net_packet_t *packet,
+                                 net_querydata_t *querydata);
 
-extern void NET_WriteTiccmdDiff(net_packet_t *packet, net_ticdiff_t *diff, boolean lowres_turn);
-extern boolean NET_ReadTiccmdDiff(net_packet_t *packet, net_ticdiff_t *diff, boolean lowres_turn);
+extern void NET_WriteTiccmdDiff(net_packet_t *packet, net_ticdiff_t *diff,
+                                boolean lowres_turn);
+extern boolean NET_ReadTiccmdDiff(net_packet_t *packet, net_ticdiff_t *diff,
+                                  boolean lowres_turn);
 extern void NET_TiccmdDiff(ticcmd_t *tic1, ticcmd_t *tic2, net_ticdiff_t *diff);
 extern void NET_TiccmdPatch(ticcmd_t *src, net_ticdiff_t *diff, ticcmd_t *dest);
 
-boolean NET_ReadFullTiccmd(net_packet_t *packet, net_full_ticcmd_t *cmd, boolean lowres_turn);
-void NET_WriteFullTiccmd(net_packet_t *packet, net_full_ticcmd_t *cmd, boolean lowres_turn);
+boolean NET_ReadFullTiccmd(net_packet_t *packet, net_full_ticcmd_t *cmd,
+                           boolean lowres_turn);
+void NET_WriteFullTiccmd(net_packet_t *packet, net_full_ticcmd_t *cmd,
+                         boolean lowres_turn);
 
 boolean NET_ReadSHA1Sum(net_packet_t *packet, sha1_digest_t digest);
 void NET_WriteSHA1Sum(net_packet_t *packet, sha1_digest_t digest);
@@ -42,9 +50,6 @@ void NET_WriteSHA1Sum(net_packet_t *packet, sha1_digest_t digest);
 void NET_WriteWaitData(net_packet_t *packet, net_waitdata_t *data);
 boolean NET_ReadWaitData(net_packet_t *packet, net_waitdata_t *data);
 
-//boolean NET_ReadPRNGSeed(net_packet_t *packet, prng_seed_t seed);
-//void NET_WritePRNGSeed(net_packet_t *packet, prng_seed_t seed);
-
 // Protocol list exchange.
 net_protocol_t NET_ReadProtocol(net_packet_t *packet);
 void NET_WriteProtocol(net_packet_t *packet, net_protocol_t protocol);
