@@ -19,23 +19,41 @@
 //
 //-----------------------------------------------------------------------------
 
+#include <stdlib.h>
+
+#include "d_items.h"
+#include "d_player.h"
+#include "d_think.h"
+#include "doomdata.h"
+#include "doomdef.h"
 #include "doomstat.h"
+#include "doomtype.h"
+#include "g_game.h"
+#include "hu_obituary.h"
 #include "i_printf.h"
+#include "i_system.h"
+#include "info.h"
+#include "m_bbox.h"
+#include "m_fixed.h"
 #include "m_random.h"
-#include "r_main.h"
-#include "p_maputl.h"
+#include "p_action.h"
+#include "p_enemy.h"
+#include "p_inter.h"
 #include "p_map.h"
+#include "p_maputl.h"
+#include "p_mobj.h"
+#include "p_pspr.h"
 #include "p_setup.h"
 #include "p_spec.h"
+#include "p_tick.h"
+#include "r_defs.h"
+#include "r_main.h"
+#include "r_state.h"
 #include "s_sound.h"
 #include "sounds.h"
-#include "p_inter.h"
-#include "g_game.h"
-#include "p_enemy.h"
-#include "p_tick.h"
-#include "m_bbox.h"
-
-#include "p_action.h"
+#include "tables.h"
+#include "u_mapinfo.h"
+#include "z_zone.h"
 
 static mobj_t *current_actor;
 
@@ -1639,6 +1657,36 @@ boolean PIT_VileCheck(mobj_t *thing)
 
 boolean ghost_monsters;
 
+static void WatchResurrection(mobj_t* target, mobj_t* raiser)
+{
+  int i;
+
+  if (raiser && (raiser->intflags & MIF_SPAWNED_BY_ICON))
+  {
+    target->intflags |= MIF_SPAWNED_BY_ICON;
+  }
+
+  if (((target->flags ^ MF_COUNTKILL) & (MF_FRIEND | MF_COUNTKILL)) ||
+      (target->intflags & MIF_SPAWNED_BY_ICON))
+  {
+    return;
+  }
+
+  for (i = 0; i < MAXPLAYERS; ++i)
+  {
+    if (!playeringame[i] || players[i].killcount == 0)
+    {
+      continue;
+    }
+
+    if (players[i].killcount > 0)
+    {
+      players[i].maxkilldiscount++;
+      return;
+    }
+  }
+}
+
 static boolean P_HealCorpse(mobj_t* actor, int radius, statenum_t healstate, sfxenum_t healsound)
 {
   int xl, xh;
@@ -1696,6 +1744,8 @@ static boolean P_HealCorpse(mobj_t* actor, int radius, statenum_t healstate, sfx
 		  corpsehit->flags = 
 		    (info->flags & ~MF_FRIEND) | (actor->flags & MF_FRIEND);
 
+		  WatchResurrection(corpsehit, actor);
+
 		  // [crispy] resurrected pools of gore ("ghost monsters") are translucent
 		  if (STRICTMODE(ghost_monsters) && corpsehit->height == 0
 		      && corpsehit->radius == 0)
@@ -1717,10 +1767,6 @@ static boolean P_HealCorpse(mobj_t* actor, int radius, statenum_t healstate, sfx
 		  // killough 8/29/98: add to appropriate thread
 		  P_UpdateThinker(&corpsehit->thinker);
 
-                  // [crispy] count resurrected monsters
-                  if (!(corpsehit->flags & MF_FRIEND))
-                    extrakills++;
-
                   return true;
                 }
             }
@@ -2569,6 +2615,18 @@ void A_SpawnSound(mobj_t *mo)
   A_SpawnFly(mo);
 }
 
+static void WatchIconSpawn(mobj_t* spawned)
+{
+  spawned->intflags |= MIF_SPAWNED_BY_ICON;
+
+  // We can't know inside P_SpawnMobj what the source is
+  // This is less invasive than introducing a spawn source concept
+  if (!((spawned->flags ^ MF_COUNTKILL) & (MF_FRIEND | MF_COUNTKILL)))
+  {
+    --max_kill_requirement;
+  }
+}
+
 void A_SpawnFly(mobj_t *mo)
 {
   mobj_t *newmobj;  // killough 8/9/98
@@ -2620,9 +2678,7 @@ void A_SpawnFly(mobj_t *mo)
   // killough 7/18/98: brain friendliness is transferred
   newmobj->flags = (newmobj->flags & ~MF_FRIEND) | (mo->flags & MF_FRIEND);
 
-  // [crispy] count spawned monsters
-  if (!(newmobj->flags & MF_FRIEND))
-    extrakills++;
+  WatchIconSpawn(newmobj);
 
   // killough 8/29/98: add to appropriate thread
   P_UpdateThinker(&newmobj->thinker);
