@@ -425,6 +425,9 @@ extern boolean colored_blood;
 extern boolean direct_vertical_aiming, default_direct_vertical_aiming;
 void P_UpdateDirectVerticalAiming(void);
 
+extern boolean checksight12;
+void P_UpdateCheckSight(void);
+
 mobj_t *P_SubstNullMobj(mobj_t *mobj);
 void    P_RespawnSpecials(void);
 mobj_t  *P_SpawnMobj(fixed_t x, fixed_t y, fixed_t z, mobjtype_t type);
