@@ -17,13 +17,19 @@
 //
 //-----------------------------------------------------------------------------
 
+#include "d_think.h"
 #include "doomstat.h"
+#include "doomtype.h"
+#include "m_fixed.h"
 #include "m_random.h"
-#include "r_main.h"
+#include "p_mobj.h"
 #include "p_spec.h"
 #include "p_tick.h"
+#include "r_defs.h"
+#include "r_state.h"
 #include "s_sound.h"
 #include "sounds.h"
+#include "z_zone.h"
 
 platlist_t *activeplats;       // killough 2/14/98: made global again
 
