@@ -228,7 +228,7 @@ static boolean P_CrossBSPNode(int bspnum, register los_t *los)
 //
 // killough 4/20/98: cleaned up, made to use new LOS struct
 
-boolean P_CheckSight(mobj_t *t1, mobj_t *t2)
+static boolean P_CheckSight_MBF(mobj_t *t1, mobj_t *t2)
 {
   const sector_t *s1 = t1->subsector->sector;
   const sector_t *s2 = t2->subsector->sector;
@@ -288,6 +288,14 @@ boolean P_CheckSight(mobj_t *t1, mobj_t *t2)
   return P_CrossBSPNode(numnodes-1, &los);
 }
 
+boolean checksight12;
+boolean (*P_CheckSight)(mobj_t *t1, mobj_t *t2) = P_CheckSight_MBF;
+
+void P_UpdateCheckSight(void)
+{
+  P_CheckSight = CRITICAL(checksight12) ? P_CheckSight_12 : P_CheckSight_MBF;
+}
+
 //
 // mbf21: P_CheckFov
 // Returns true if t2 is within t1's field of view.
