@@ -501,8 +501,8 @@ static void R_SetupFreelook(void)
     dy = 0;
   }
 
-  centeryfrac = (viewheight << FRACBITS) / 2 + dy;
-  centery = centeryfrac >> FRACBITS;
+  centery = viewheight / 2 + (dy >> FRACBITS);
+  centeryfrac = centery << FRACBITS;
 
   for (i = 0; i < viewheight; i++)
   {
@@ -626,7 +626,7 @@ void R_ExecuteSetViewSize (void)
 
       for (j=0 ; j<MAXLIGHTSCALE ; j++)
         {                                       // killough 11/98:
-          int t, level = startmap - j*NONWIDEWIDTH/scaledviewwidth_nonwide/DISTMAP;
+          int t, level = startmap - j / DISTMAP;
 
           if (level < 0)
             level = 0;
