@@ -20,7 +20,7 @@
 #ifndef __R_SKY__
 #define __R_SKY__
 
-#include "m_fixed.h"
+#include "doomtype.h"
 
 // SKY, store the number for name.
 #define SKYFLATNAME  "F_SKY1"
