@@ -25,9 +25,8 @@
 #include "m_array.h"
 #include "m_bbox.h"
 #include "m_fixed.h"
-#include "m_menu.h"
+#include "mn_menu.h"
 #include "m_misc.h"
-#include "m_misc2.h"
 #include "p_mobj.h"
 #include "r_bmaps.h"
 #include "r_defs.h"
@@ -305,7 +304,7 @@ void VX_Init (void)
 	{
 		I_Printf(VB_INFO, "Voxels not found.");
 		voxels_rendering = false;
-		M_DisableVoxelsRenderingItem();
+		MN_DisableVoxelsRenderingItem();
 		return;
 	}
 
@@ -338,7 +337,7 @@ void VX_Init (void)
 	if (!voxels_found)
 	{
 		voxels_rendering = false;
-		M_DisableVoxelsRenderingItem();
+		MN_DisableVoxelsRenderingItem();
 	}
 }
 
