@@ -21,19 +21,25 @@
 //
 //-----------------------------------------------------------------------------
 
+#include <errno.h>
 #include <stdlib.h>
 #include <string.h>
 
+#include "d_main.h"
 #include "doomdef.h"
+#include "doomstat.h"
 #include "doomtype.h"
 #include "i_system.h"
 #include "i_video.h"
 #include "m_argv.h"
-#include "m_misc2.h"
+#include "m_io.h"
+#include "m_misc.h"
 #include "m_swap.h"
 #include "r_data.h"
 #include "r_defs.h"
 #include "r_state.h"
+#include "s_sound.h"
+#include "sounds.h"
 #include "v_trans.h"
 #include "v_video.h"
 #include "w_wad.h" // needed for color translation lump lookup
@@ -45,8 +51,8 @@ pixel_t *I_VideoBuffer;
 
 static pixel_t *dest_screen = NULL;
 
-//jff 2/18/98 palette color ranges for translation
-//jff 4/24/98 now pointers set to predefined lumps to allow overloading
+// jff 2/18/98 palette color ranges for translation
+// jff 4/24/98 now pointers set to predefined lumps to allow overloading
 
 byte *cr_brick;
 byte *cr_tan;
@@ -67,7 +73,7 @@ byte *cr_dark;
 byte *cr_shaded;
 byte *cr_bright;
 
-//jff 4/24/98 initialize this at runtime
+// jff 4/24/98 initialize this at runtime
 byte *colrngs[CR_LIMIT] = {0};
 byte *red2col[CR_LIMIT] = {0};
 
@@ -84,111 +90,127 @@ byte *red2col[CR_LIMIT] = {0};
 // provided in v_video.h.
 //
 
-typedef struct {
-  const char *name;
-  byte **map1, **map2, **map_orig;
+typedef struct
+{
+    const char *name;
+    byte **map1, **map2, **map_orig;
 } crdef_t;
 
 // killough 5/2/98: table-driven approach
-static const crdef_t crdefs[] = {
-  {"CRBRICK",  &cr_brick,   &colrngs[CR_BRICK ], &red2col[CR_BRICK ]},
-  {"CRTAN",    &cr_tan,     &colrngs[CR_TAN   ], &red2col[CR_TAN   ]},
-  {"CRGRAY",   &cr_gray,    &colrngs[CR_GRAY  ], &red2col[CR_GRAY  ]},
-  {"CRGREEN",  &cr_green,   &colrngs[CR_GREEN ], &red2col[CR_GREEN ]},
-  {"CRBROWN",  &cr_brown,   &colrngs[CR_BROWN ], &red2col[CR_BROWN ]},
-  {"CRGOLD",   &cr_gold,    &colrngs[CR_GOLD  ], &red2col[CR_GOLD  ]},
-  {"CRRED",    &cr_red,     &colrngs[CR_RED   ], &red2col[CR_RED   ]},
-  {"CRBLUE",   &cr_blue,    &colrngs[CR_BLUE1 ], &red2col[CR_BLUE1 ]},
-  {"CRORANGE", &cr_orange,  &colrngs[CR_ORANGE], &red2col[CR_ORANGE]},
-  {"CRYELLOW", &cr_yellow,  &colrngs[CR_YELLOW], &red2col[CR_YELLOW]},
-  {"CRBLUE2",  &cr_blue2,   &colrngs[CR_BLUE2 ], &red2col[CR_BLUE2 ]},
-  {"CRBLACK",  &cr_black,   &colrngs[CR_BLACK ], &red2col[CR_BLACK ]},
-  {"CRPURPLE", &cr_purple,  &colrngs[CR_PURPLE], &red2col[CR_PURPLE]},
-  {"CRWHITE",  &cr_white,   &colrngs[CR_WHITE ], &red2col[CR_WHITE ]},
-  {NULL}
+static const crdef_t crdefs[] =
+{
+    {"CRBRICK",  &cr_brick,  &colrngs[CR_BRICK],  &red2col[CR_BRICK]},
+    {"CRTAN",    &cr_tan,    &colrngs[CR_TAN],    &red2col[CR_TAN]},
+    {"CRGRAY",   &cr_gray,   &colrngs[CR_GRAY],   &red2col[CR_GRAY]},
+    {"CRGREEN",  &cr_green,  &colrngs[CR_GREEN],  &red2col[CR_GREEN]},
+    {"CRBROWN",  &cr_brown,  &colrngs[CR_BROWN],  &red2col[CR_BROWN]},
+    {"CRGOLD",   &cr_gold,   &colrngs[CR_GOLD],   &red2col[CR_GOLD]},
+    {"CRRED",    &cr_red,    &colrngs[CR_RED],    &red2col[CR_RED]},
+    {"CRBLUE",   &cr_blue,   &colrngs[CR_BLUE1],  &red2col[CR_BLUE1]},
+    {"CRORANGE", &cr_orange, &colrngs[CR_ORANGE], &red2col[CR_ORANGE]},
+    {"CRYELLOW", &cr_yellow, &colrngs[CR_YELLOW], &red2col[CR_YELLOW]},
+    {"CRBLUE2",  &cr_blue2,  &colrngs[CR_BLUE2],  &red2col[CR_BLUE2]},
+    {"CRBLACK",  &cr_black,  &colrngs[CR_BLACK],  &red2col[CR_BLACK]},
+    {"CRPURPLE", &cr_purple, &colrngs[CR_PURPLE], &red2col[CR_PURPLE]},
+    {"CRWHITE",  &cr_white,  &colrngs[CR_WHITE],  &red2col[CR_WHITE]},
+    {NULL}
 };
 
 // [FG] translate between blood color value as per EE spec
 //      and actual color translation table index
 
-static const int bloodcolor[] = {
-  CR_RED,    // 0 - Red (normal)
-  CR_GRAY,   // 1 - Grey
-  CR_GREEN,  // 2 - Green
-  CR_BLUE2,  // 3 - Blue
-  CR_YELLOW, // 4 - Yellow
-  CR_BLACK,  // 5 - Black
-  CR_PURPLE, // 6 - Purple
-  CR_WHITE,  // 7 - White
-  CR_ORANGE, // 8 - Orange
+static const int bloodcolor[] =
+{
+    CR_RED,     // 0 - Red (normal)
+    CR_GRAY,    // 1 - Grey
+    CR_GREEN,   // 2 - Green
+    CR_BLUE2,   // 3 - Blue
+    CR_YELLOW,  // 4 - Yellow
+    CR_BLACK,   // 5 - Black
+    CR_PURPLE,  // 6 - Purple
+    CR_WHITE,   // 7 - White
+    CR_ORANGE,  // 8 - Orange
 };
 
 int V_BloodColor(int blood)
 {
-  return bloodcolor[blood];
+    return bloodcolor[blood];
 }
 
 int v_lightest_color, v_darkest_color;
 
+byte invul_gray[256];
+
 // killough 5/2/98: tiny engine driven by table above
 void V_InitColorTranslation(void)
 {
-  register const crdef_t *p;
+    register const crdef_t *p;
 
-  int playpal_lump = W_GetNumForName("PLAYPAL");
-  byte *playpal = W_CacheLumpNum(playpal_lump, PU_STATIC);
-  boolean iwad_playpal = W_IsIWADLump(playpal_lump);
+    int playpal_lump = W_GetNumForName("PLAYPAL");
+    byte *playpal = W_CacheLumpNum(playpal_lump, PU_STATIC);
+    boolean iwad_playpal = W_IsIWADLump(playpal_lump);
 
-  int force_rebuild = M_CheckParm("-tranmap");
+    int force_rebuild = M_CheckParm("-tranmap");
 
-  // [crispy] preserve gray drop shadow in IWAD status bar numbers
-  boolean keepgray = W_IsIWADLump(W_GetNumForName("sttnum0"));
+    // [crispy] preserve gray drop shadow in IWAD status bar numbers
+    boolean keepgray = W_IsIWADLump(W_GetNumForName("sttnum0"));
 
-  for (p = crdefs; p->name; p++)
-  {
-    int i, lumpnum = W_GetNumForName(p->name);
-
-    *p->map_orig = W_CacheLumpNum(lumpnum, PU_STATIC);
-
-    // [FG] color translation table provided by PWAD
-    if (W_IsWADLump(lumpnum) && !force_rebuild)
+    for (p = crdefs; p->name; p++)
     {
-      *p->map1 = *p->map2 = *p->map_orig;
-      continue;
-    }
+        int i, lumpnum = W_GetNumForName(p->name);
 
-    // [FG] allocate new color translation table
-    *p->map2 = malloc(256);
+        *p->map_orig = W_CacheLumpNum(lumpnum, PU_STATIC);
 
-    // [FG] translate all colors to target color
-    for (i = 0; i < 256; i++)
-    {
-      (*p->map2)[i] = V_Colorize(playpal, p - crdefs, (byte) i);
-    }
-
-    // [FG] override with original color translations
-    if (iwad_playpal && !force_rebuild)
-    {
-      for (i = 0; i < 256; i++)
-      {
-        if (((*p->map_orig)[i] != (char) i) || (keepgray && i == 109))
+        // [FG] color translation table provided by PWAD
+        if (W_IsWADLump(lumpnum) && !force_rebuild)
         {
-          (*p->map2)[i] = (*p->map_orig)[i];
+            *p->map1 = *p->map2 = *p->map_orig;
+            continue;
         }
-      }
+
+        // [FG] allocate new color translation table
+        *p->map2 = malloc(256);
+
+        // [FG] translate all colors to target color
+        for (i = 0; i < 256; i++)
+        {
+            (*p->map2)[i] = V_Colorize(playpal, p - crdefs, (byte)i);
+        }
+
+        // [FG] override with original color translations
+        if (iwad_playpal && !force_rebuild)
+        {
+            for (i = 0; i < 256; i++)
+            {
+                if (((*p->map_orig)[i] != (char)i) || (keepgray && i == 109))
+                {
+                    (*p->map2)[i] = (*p->map_orig)[i];
+                }
+            }
+        }
+
+        *p->map1 = *p->map2;
     }
 
-    *p->map1 = *p->map2;
-  }
+    cr_bright = malloc(256);
+    for (int i = 0; i < 256; ++i)
+    {
+        cr_bright[i] = V_Colorize(playpal, CR_BRIGHT, (byte)i);
+    }
 
-  cr_bright = malloc(256);
-  for (int i = 0; i < 256; ++i)
-  {
-    cr_bright[i] = V_Colorize(playpal, CR_BRIGHT, (byte)i);
-  }
+    v_lightest_color = I_GetPaletteIndex(playpal, 0xFF, 0xFF, 0xFF);
+    v_darkest_color  = I_GetPaletteIndex(playpal, 0x00, 0x00, 0x00);
 
-  v_lightest_color = I_GetPaletteIndex(playpal, 0xFF, 0xFF, 0xFF);
-  v_darkest_color  = I_GetPaletteIndex(playpal, 0x00, 0x00, 0x00);
+    byte *palsrc = playpal;
+    for (int i = 0; i < 256; ++i)
+    {
+        double red   = *palsrc++ / 256.0;
+        double green = *palsrc++ / 256.0;
+        double blue  = *palsrc++ / 256.0;
+
+        int gray = (red * 0.299 + green * 0.587 + blue * 0.144) * 255;
+        invul_gray[i] = I_GetPaletteIndex(playpal, gray, gray, gray);
+    }
 }
 
 void WriteGeneratedLumpWad(const char *filename)
@@ -244,10 +266,10 @@ static void (*drawcolfunc)(const patch_column_t *patchcol);
 
 static void V_DrawPatchColumn(const patch_column_t *patchcol)
 {
-    int      count;
-    byte     *dest;    // killough
-    fixed_t  frac;     // killough
-    fixed_t  fracstep;
+    int count;
+    byte *dest;   // killough
+    fixed_t frac; // killough
+    fixed_t fracstep;
 
     count = patchcol->y2 - patchcol->y1 + 1;
 
@@ -257,8 +279,8 @@ static void V_DrawPatchColumn(const patch_column_t *patchcol)
     }
 
 #ifdef RANGECHECK
-    if ((unsigned int)patchcol->x  >= (unsigned int)video.width ||
-        (unsigned int)patchcol->y1 >= (unsigned int)video.height)
+    if ((unsigned int)patchcol->x >= (unsigned int)video.width
+        || (unsigned int)patchcol->y1 >= (unsigned int)video.height)
     {
         I_Error("V_DrawPatchColumn: %i to %i at %i", patchcol->y1, patchcol->y2,
                 patchcol->x);
@@ -290,16 +312,18 @@ static void V_DrawPatchColumn(const patch_column_t *patchcol)
             frac += fracstep;
         }
         if (count & 1)
+        {
             *dest = source[frac >> FRACBITS];
+        }
     }
 }
 
 static void V_DrawPatchColumnTR(const patch_column_t *patchcol)
 {
-    int      count;
-    byte     *dest;    // killough
-    fixed_t  frac;     // killough
-    fixed_t  fracstep;
+    int count;
+    byte *dest;   // killough
+    fixed_t frac; // killough
+    fixed_t fracstep;
 
     count = patchcol->y2 - patchcol->y1 + 1;
 
@@ -309,8 +333,8 @@ static void V_DrawPatchColumnTR(const patch_column_t *patchcol)
     }
 
 #ifdef RANGECHECK
-    if ((unsigned int)patchcol->x  >= (unsigned int)video.width ||
-        (unsigned int)patchcol->y1 >= (unsigned int)video.height)
+    if ((unsigned int)patchcol->x >= (unsigned int)video.width
+        || (unsigned int)patchcol->y1 >= (unsigned int)video.height)
     {
         I_Error("V_DrawPatchColumn: %i to %i at %i", patchcol->y1, patchcol->y2,
                 patchcol->x);
@@ -350,10 +374,10 @@ static void V_DrawPatchColumnTR(const patch_column_t *patchcol)
 
 static void V_DrawPatchColumnTRTR(const patch_column_t *patchcol)
 {
-    int      count;
-    byte     *dest;    // killough
-    fixed_t  frac;     // killough
-    fixed_t  fracstep;
+    int count;
+    byte *dest;   // killough
+    fixed_t frac; // killough
+    fixed_t fracstep;
 
     count = patchcol->y2 - patchcol->y1 + 1;
 
@@ -363,8 +387,8 @@ static void V_DrawPatchColumnTRTR(const patch_column_t *patchcol)
     }
 
 #ifdef RANGECHECK
-    if ((unsigned int)patchcol->x  >= (unsigned int)video.width ||
-        (unsigned int)patchcol->y1 >= (unsigned int)video.height)
+    if ((unsigned int)patchcol->x >= (unsigned int)video.width
+        || (unsigned int)patchcol->y1 >= (unsigned int)video.height)
     {
         I_Error("V_DrawPatchColumn: %i to %i at %i", patchcol->y1, patchcol->y2,
                 patchcol->x);
@@ -405,7 +429,8 @@ static void V_DrawPatchColumnTRTR(const patch_column_t *patchcol)
 static void V_DrawMaskedColumn(patch_column_t *patchcol, const int ytop,
                                column_t *column)
 {
-    for (; column->topdelta != 0xff; column = (column_t *)((byte *)column + column->length + 4))
+    for (; column->topdelta != 0xff;
+         column = (column_t *)((byte *)column + column->length + 4))
     {
         // calculate unclipped screen coordinates for post
         int columntop = ytop + column->topdelta;
@@ -414,7 +439,9 @@ static void V_DrawMaskedColumn(patch_column_t *patchcol, const int ytop,
         {
             // SoM: Make sure the lut is never referenced out of range
             if (columntop >= SCREENHEIGHT)
+            {
                 return;
+            }
 
             patchcol->y1 = y1lookup[columntop];
             patchcol->frac = 0;
@@ -426,16 +453,22 @@ static void V_DrawMaskedColumn(patch_column_t *patchcol, const int ytop,
         }
 
         if (columntop + column->length - 1 < 0)
+        {
             continue;
+        }
         if (columntop + column->length - 1 < SCREENHEIGHT)
+        {
             patchcol->y2 = y2lookup[columntop + column->length - 1];
+        }
         else
+        {
             patchcol->y2 = y2lookup[SCREENHEIGHT - 1];
+        }
 
         // SoM: The failsafes should be completely redundant now...
         // haleyjd 05/13/08: fix clipping; y2lookup not clamped properly
-        if ((column->length > 0 && patchcol->y2 < patchcol->y1) ||
-            patchcol->y2 >= video.height)
+        if ((column->length > 0 && patchcol->y2 < patchcol->y1)
+            || patchcol->y2 >= video.height)
         {
             patchcol->y2 = video.height - 1;
         }
@@ -451,8 +484,8 @@ static void V_DrawMaskedColumn(patch_column_t *patchcol, const int ytop,
 
 static void V_DrawPatchInt(int x, int y, patch_t *patch, boolean flipped)
 {
-    int        x1, x2, w;
-    fixed_t    iscale, xiscale, startfrac = 0;
+    int x1, x2, w;
+    fixed_t iscale, xiscale, startfrac = 0;
     patch_column_t patchcol = {0};
 
     w = SHORT(patch->width);
@@ -471,35 +504,49 @@ static void V_DrawPatchInt(int x, int y, patch_t *patch, boolean flipped)
         x2 = x1 + w - 1;
     }
 
-    iscale        = video.xstep;
+    iscale = video.xstep;
     patchcol.step = video.ystep;
 
     // off the left or right side?
     if (x2 < 0 || x1 >= video.unscaledw)
+    {
         return;
+    }
 
     xiscale = flipped ? -iscale : iscale;
 
     // haleyjd 10/10/08: must handle coordinates outside the screen buffer
     // very carefully here.
     if (x1 >= 0)
+    {
         x1 = x1lookup[x1];
+    }
     else if (-x1 - 1 < video.unscaledw)
+    {
         x1 = -x2lookup[-x1 - 1];
+    }
     else // too far off-screen
+    {
         x1 = (x1 * video.xscale) >> FRACBITS;
+    }
 
     if (x2 < video.unscaledw)
+    {
         x2 = x2lookup[x2];
+    }
     else
+    {
         x2 = x2lookup[video.unscaledw - 1];
+    }
 
     patchcol.x = (x1 < 0) ? 0 : x1;
 
     // SoM: Any time clipping occurs on screen coords, the resulting clipped
     // coords should be checked to make sure we are still on screen.
     if (x2 < x1)
+    {
         return;
+    }
 
     // SoM: Ok, so the startfrac should ALWAYS be the last post of the patch
     // when the patch is flipped minus the fractional "bump" from the screen
@@ -509,30 +556,37 @@ static void V_DrawPatchInt(int x, int y, patch_t *patch, boolean flipped)
     // will create some fractional bump down, so it is safe to assume this puts
     // us just below patch->width << 16
     if (flipped)
+    {
         startfrac = (w << 16) - ((x1 * iscale) & 0xffff) - 1;
+    }
     else
+    {
         startfrac = (x1 * iscale) & 0xffff;
+    }
 
     if (patchcol.x > x1)
+    {
         startfrac += xiscale * (patchcol.x - x1);
+    }
 
     {
         column_t *column;
-        int      texturecolumn;
+        int texturecolumn;
 
         const int ytop = y - SHORT(patch->topoffset);
-        for ( ; patchcol.x <= x2; patchcol.x++, startfrac += xiscale)
+        for (; patchcol.x <= x2; patchcol.x++, startfrac += xiscale)
         {
             texturecolumn = startfrac >> FRACBITS;
 
-    #ifdef RANGECHECK
+#ifdef RANGECHECK
             if (texturecolumn < 0 || texturecolumn >= w)
             {
                 I_Error("V_DrawPatchInt: bad texturecolumn %d", texturecolumn);
             }
-    #endif
+#endif
 
-            column = (column_t *)((byte *)patch + LONG(patch->columnofs[texturecolumn]));
+            column = (column_t *)((byte *)patch
+                                  + LONG(patch->columnofs[texturecolumn]));
             V_DrawMaskedColumn(&patchcol, ytop, column);
         }
     }
@@ -605,8 +659,8 @@ void V_DrawPatchFullScreen(patch_t *patch)
     if (video.unscaledw != NONWIDEWIDTH)
     {
         V_FillRect(0, 0, video.deltaw, SCREENHEIGHT, v_darkest_color);
-        V_FillRect(video.unscaledw - video.deltaw, 0,
-                   video.deltaw, SCREENHEIGHT, v_darkest_color);
+        V_FillRect(video.unscaledw - video.deltaw, 0, video.deltaw,
+                   SCREENHEIGHT, v_darkest_color);
     }
 
     drawcolfunc = V_DrawPatchColumn;
@@ -644,9 +698,13 @@ static void V_ClipRect(vrect_t *rect)
 
     // clip right and bottom edges
     if (rect->cx2 >= video.unscaledw)
-        rect->cx2 =  video.unscaledw - 1;
+    {
+        rect->cx2 = video.unscaledw - 1;
+    }
     if (rect->cy2 >= SCREENHEIGHT)
-        rect->cy2 =  SCREENHEIGHT - 1;
+    {
+        rect->cy2 = SCREENHEIGHT - 1;
+    }
 
     // determine clipped width and height
     rect->cw = rect->cx2 - rect->cx1 + 1;
@@ -674,11 +732,13 @@ void V_FillRect(int x, int y, int width, int height, byte color)
 
     // clipped away completely?
     if (dstrect.cw <= 0 || dstrect.ch <= 0)
+    {
         return;
+    }
 
     V_ScaleClippedRect(&dstrect);
 
-    byte* dest = V_ADDRESS(dest_screen, dstrect.sx, dstrect.sy);
+    byte *dest = V_ADDRESS(dest_screen, dstrect.sx, dstrect.sy);
 
     while (dstrect.sh--)
     {
@@ -695,8 +755,7 @@ void V_FillRect(int x, int y, int width, int height, byte color)
 // destination origin in destx,desty, common size in width and height.
 //
 
-void V_CopyRect(int srcx, int srcy, pixel_t *source,
-                int width, int height,
+void V_CopyRect(int srcx, int srcy, pixel_t *source, int width, int height,
                 int destx, int desty)
 {
     vrect_t srcrect, dstrect;
@@ -704,10 +763,9 @@ void V_CopyRect(int srcx, int srcy, pixel_t *source,
     int usew, useh;
 
 #ifdef RANGECHECK
-    if (srcx + width < 0 || srcy + height < 0 ||
-        srcx >= video.unscaledw || srcy >= SCREENHEIGHT ||
-        destx + width < 0 || desty + height < 0 ||
-        destx >= video.unscaledw || desty >= SCREENHEIGHT)
+    if (srcx + width < 0 || srcy + height < 0 || srcx >= video.unscaledw
+        || srcy >= SCREENHEIGHT || destx + width < 0 || desty + height < 0
+        || destx >= video.unscaledw || desty >= SCREENHEIGHT)
     {
         I_Error("Bad V_CopyRect");
     }
@@ -722,7 +780,9 @@ void V_CopyRect(int srcx, int srcy, pixel_t *source,
 
     // clipped away completely?
     if (srcrect.cw <= 0 || srcrect.ch <= 0)
+    {
         return;
+    }
 
     V_ScaleClippedRect(&srcrect);
 
@@ -735,7 +795,9 @@ void V_CopyRect(int srcx, int srcy, pixel_t *source,
 
     // clipped away completely?
     if (dstrect.cw <= 0 || dstrect.ch <= 0)
+    {
         return;
+    }
 
     V_ScaleClippedRect(&dstrect);
 
@@ -743,7 +805,7 @@ void V_CopyRect(int srcx, int srcy, pixel_t *source,
     usew = (srcrect.sw < dstrect.sw ? srcrect.sw : dstrect.sw);
     useh = (srcrect.sh < dstrect.sh ? srcrect.sh : dstrect.sh);
 
-    src  = V_ADDRESS(source, srcrect.sx, srcrect.sy);
+    src = V_ADDRESS(source, srcrect.sx, srcrect.sy);
     dest = V_ADDRESS(dest_screen, dstrect.sx, dstrect.sy);
 
     while (useh--)
@@ -757,7 +819,7 @@ void V_CopyRect(int srcx, int srcy, pixel_t *source,
 //
 // V_DrawBlock
 //
-// Draw a linear block of pixels into the view buffer. 
+// Draw a linear block of pixels into the view buffer.
 //
 // The bytes at src are copied in linear order to the screen rectangle
 // at x,y in screenbuffer scrn, with size width by height.
@@ -778,7 +840,9 @@ void V_DrawBlock(int x, int y, int width, int height, pixel_t *src)
 
     // clipped away completely?
     if (dstrect.cw <= 0 || dstrect.ch <= 0)
+    {
         return;
+    }
 
     // change in origin due to clipping
     int dx = dstrect.cx1 - x;
@@ -790,10 +854,10 @@ void V_DrawBlock(int x, int y, int width, int height, pixel_t *src)
     dest = V_ADDRESS(dest_screen, dstrect.sx, dstrect.sy);
 
     {
-        int     w;
+        int w;
         fixed_t xfrac, yfrac;
-        int     xtex, ytex;
-        byte    *row;
+        int xtex, ytex;
+        byte *row;
 
         yfrac = 0;
 
@@ -867,23 +931,22 @@ void V_TileBlock64(int line, int width, int height, const byte *src)
 
 void V_GetBlock(int x, int y, int width, int height, byte *dest)
 {
-  byte *src;
+    byte *src;
 
 #ifdef RANGECHECK
-  if (x<0
-      || x+width >video.width
-      || y<0
-      || y+height>video.height )
-    I_Error ("Bad V_GetBlock");
+    if (x < 0 || x + width > video.width || y < 0 || y + height > video.height)
+    {
+        I_Error("Bad V_GetBlock");
+    }
 #endif
 
-  src = V_ADDRESS(dest_screen, x, y);
+    src = V_ADDRESS(dest_screen, x, y);
 
-  while (height--)
+    while (height--)
     {
-      memcpy (dest, src, width);
-      src += linesize;
-      dest += width;
+        memcpy(dest, src, width);
+        src += linesize;
+        dest += width;
     }
 }
 
@@ -891,23 +954,22 @@ void V_GetBlock(int x, int y, int width, int height, byte *dest)
 
 void V_PutBlock(int x, int y, int width, int height, byte *src)
 {
-  byte *dest;
+    byte *dest;
 
 #ifdef RANGECHECK
-  if (x<0
-      ||x+width >video.width
-      || y<0
-      || y+height>video.height )
-    I_Error ("Bad V_PutBlock");
+    if (x < 0 || x + width > video.width || y < 0 || y + height > video.height)
+    {
+        I_Error("Bad V_PutBlock");
+    }
 #endif
 
-  dest = V_ADDRESS(dest_screen, x, y);
+    dest = V_ADDRESS(dest_screen, x, y);
 
-  while (height--)
+    while (height--)
     {
-      memcpy (dest, src, width);
-      dest += linesize;
-      src += width;
+        memcpy(dest, src, width);
+        dest += linesize;
+        src += width;
     }
 }
 
@@ -935,7 +997,8 @@ void V_ShadeScreen(void)
 
 void V_DrawBackground(const char *patchname)
 {
-    const byte *src = W_CacheLumpNum(firstflat + R_FlatNumForName(patchname), PU_CACHE);
+    const byte *src =
+        W_CacheLumpNum(firstflat + R_FlatNumForName(patchname), PU_CACHE);
 
     V_TileBlock64(0, video.unscaledw, SCREENHEIGHT, src);
 }
@@ -946,19 +1009,18 @@ void V_DrawBackground(const char *patchname)
 
 void V_Init(void)
 {
-    int i;
     fixed_t frac, lastfrac;
 
     linesize = video.pitch;
 
     video.xscale = (video.width << FRACBITS) / video.unscaledw;
     video.yscale = (video.height << FRACBITS) / SCREENHEIGHT;
-    video.xstep  = ((video.unscaledw << FRACBITS) / video.width) + 1;
-    video.ystep  = ((SCREENHEIGHT << FRACBITS) / video.height) + 1;
+    video.xstep = ((video.unscaledw << FRACBITS) / video.width) + 1;
+    video.ystep = ((SCREENHEIGHT << FRACBITS) / video.height) + 1;
 
     x1lookup[0] = 0;
     lastfrac = frac = 0;
-    for (i = 0; i < video.width; i++)
+    for (int i = 0; i < video.width; i++)
     {
         if (frac >> FRACBITS > lastfrac >> FRACBITS)
         {
@@ -974,7 +1036,7 @@ void V_Init(void)
 
     y1lookup[0] = 0;
     lastfrac = frac = 0;
-    for (i = 0; i < video.height; i++)
+    for (int i = 0; i < video.height; i++)
     {
         if (frac >> FRACBITS > lastfrac >> FRACBITS)
         {
@@ -1003,6 +1065,279 @@ void V_RestoreBuffer(void)
     dest_screen = I_VideoBuffer;
 }
 
+typedef struct
+{
+    byte row_off;
+    byte *pixels;
+} vpost_t;
+
+typedef struct
+{
+    vpost_t *posts;
+} vcolumn_t;
+
+#define M_ARRAY_INIT_CAPACITY 16
+#include "m_array.h"
+
+#define PUTBYTE(r, v)  \
+    *r = (uint8_t)(v); \
+    ++r
+
+#define PUTSHORT(r, v)                              \
+    *(r + 0) = (byte)(((uint16_t)(v) >> 0) & 0xff); \
+    *(r + 1) = (byte)(((uint16_t)(v) >> 8) & 0xff); \
+    r += 2
+
+#define PUTLONG(r, v)                                \
+    *(r + 0) = (byte)(((uint32_t)(v) >> 0) & 0xff);  \
+    *(r + 1) = (byte)(((uint32_t)(v) >> 8) & 0xff);  \
+    *(r + 2) = (byte)(((uint32_t)(v) >> 16) & 0xff); \
+    *(r + 3) = (byte)(((uint32_t)(v) >> 24) & 0xff); \
+    r += 4
+
+//
+// Converts a linear graphic to a patch with transparency. Mostly straight
+// from psxwadgen, which is mostly straight from SLADE.
+//
+patch_t *V_LinearToTransPatch(const byte *data, int width, int height,
+                              int color_key)
+{
+    vcolumn_t *columns = NULL;
+
+    // Go through columns
+    uint32_t offset = 0;
+    for (int c = 0; c < width; c++)
+    {
+        vcolumn_t col = {0};
+        vpost_t post = {0};
+        post.row_off = 0;
+        boolean ispost = false;
+        boolean first_254 = true; // first 254 pixels use absolute offsets
+
+        offset = c;
+        byte row_off = 0;
+        for (int r = 0; r < height; r++)
+        {
+            // if we're at offset 254, create a dummy post for tall doom gfx
+            // support
+            if (row_off == 254)
+            {
+                // Finish current post if any
+                if (ispost)
+                {
+                    array_push(col.posts, post);
+                    post.pixels = NULL;
+                    ispost = false;
+                }
+
+                // Begin relative offsets
+                first_254 = false;
+
+                // Create dummy post
+                post.row_off = 254;
+                array_push(col.posts, post);
+
+                // Clear post
+                row_off = 0;
+                ispost = false;
+            }
+
+            // If the current pixel is not transparent, add it to the current
+            // post
+            if (data[offset] != color_key)
+            {
+                // If we're not currently building a post, begin one and set its
+                // offset
+                if (!ispost)
+                {
+                    // Set offset
+                    post.row_off = row_off;
+
+                    // Reset offset if we're in relative offsets mode
+                    if (!first_254)
+                    {
+                        row_off = 0;
+                    }
+
+                    // Start post
+                    ispost = true;
+                }
+
+                // Add the pixel to the post
+                array_push(post.pixels, data[offset]);
+            }
+            else if (ispost)
+            {
+                // If the current pixel is transparent and we are currently
+                // building a post, add the current post to the list and clear
+                // it
+                array_push(col.posts, post);
+                post.pixels = NULL;
+                ispost = false;
+            }
+
+            // Go to next row
+            offset += width;
+            ++row_off;
+        }
+
+        // If the column ended with a post, add it
+        if (ispost)
+        {
+            array_push(col.posts, post);
+        }
+
+        // Add the column data
+        array_push(columns, col);
+
+        // Go to next column
+        ++offset;
+    }
+
+    size_t size = 0;
+
+    // Calculate needed memory size to allocate patch buffer
+    size += 4 * sizeof(int16_t);                   // 4 header shorts
+    size += array_size(columns) * sizeof(int32_t); // offsets table
+
+    for (int c = 0; c < array_size(columns); c++)
+    {
+        for (int p = 0; p < array_size(columns[c].posts); p++)
+        {
+            size_t post_len = 0;
+
+            post_len += 2; // two bytes for post header
+            post_len += 1; // dummy byte
+            post_len += array_size(columns[c].posts[p].pixels); // pixels
+            post_len += 1; // dummy byte
+
+            size += post_len;
+        }
+
+        size += 1; // room for 0xff cap byte
+    }
+
+    byte *output = malloc(size);
+    byte *rover = output;
+
+    // write header fields
+    PUTSHORT(rover, width);
+    PUTSHORT(rover, height);
+    // This is written to afterwards
+    PUTSHORT(rover, 0);
+    PUTSHORT(rover, 0);
+
+    // set starting position of column offsets table, and skip over it
+    byte *col_offsets = rover;
+    rover += array_size(columns) * 4;
+
+    for (int c = 0; c < array_size(columns); c++)
+    {
+        // write column offset to offset table
+        uint32_t offs = (uint32_t)(rover - output);
+        PUTLONG(col_offsets, offs);
+
+        // write column posts
+        for (int p = 0; p < array_size(columns[c].posts); p++)
+        {
+            // Write row offset
+            PUTBYTE(rover, columns[c].posts[p].row_off);
+
+            // Write number of pixels
+            int numpixels = array_size(columns[c].posts[p].pixels);
+            PUTBYTE(rover, numpixels);
+
+            // Write pad byte
+            byte lastval = numpixels ? columns[c].posts[p].pixels[0] : 0;
+            PUTBYTE(rover, lastval);
+
+            // Write pixels
+            for (int a = 0; a < numpixels; a++)
+            {
+                lastval = columns[c].posts[p].pixels[a];
+                PUTBYTE(rover, lastval);
+            }
+
+            // Write pad byte
+            PUTBYTE(rover, lastval);
+
+            array_free(columns[c].posts[p].pixels);
+        }
+
+        // Write 255 cap byte
+        PUTBYTE(rover, 0xff);
+
+        array_free(columns[c].posts);
+    }
+
+    array_free(columns);
+
+    // Done!
+    return (patch_t *)output;
+}
+
+//
+// V_ScreenShot
+//
+// Modified by Lee Killough so that any number of shots can be taken,
+// the code is faster, and no annoying "screenshot" message appears.
+//
+// killough 10/98: improved error-handling
+
+void V_ScreenShot(void)
+{
+    boolean success = false;
+
+    errno = 0;
+
+    if (!M_access(screenshotdir,2))
+    {
+        static int shot;
+        char lbmname[16] = {0};
+        int tries = 10000;
+        char *screenshotname = NULL;
+
+        do
+        {
+            M_snprintf(lbmname, sizeof(lbmname), "%.4s%04d.png",
+                       D_DoomExeName(), shot++); // [FG] PNG
+            if (screenshotname)
+              free(screenshotname);
+            screenshotname = M_StringJoin(screenshotdir, DIR_SEPARATOR_S,
+                                          lbmname, NULL);
+        }
+        while (!M_access(screenshotname,0) && --tries);
+
+        if (tries)
+        {
+            // killough 10/98: detect failure and remove file if error
+            // killough 11/98: add hires support
+            if (!(success = I_WritePNGfile(screenshotname))) // [FG] PNG
+            {
+                int t = errno;
+                M_remove(screenshotname);
+                errno = t;
+            }
+        }
+        if (screenshotname)
+        {
+            free(screenshotname);
+        }
+    }
+
+    // 1/18/98 killough: replace "SCREEN SHOT" acknowledgement with sfx
+    // players[consoleplayer].message = "screen shot"
+
+    // killough 10/98: print error message and change sound effect if error
+    S_StartSound(NULL,
+                 !success
+                 ? displaymsg("%s", errno ? strerror(errno)
+                                          : "Could not take screenshot"),
+                 sfx_oof
+                 : gamemode == commercial ? sfx_radio
+                                          : sfx_tink);
+}
+
 //----------------------------------------------------------------------------
 //
 // $Log: v_video.c,v $
@@ -1037,4 +1372,3 @@ void V_RestoreBuffer(void)
 // Lee's Jan 19 sources
 //
 //----------------------------------------------------------------------------
-
