@@ -28,9 +28,10 @@
 #include "g_game.h"
 #include "hu_lib.h"
 #include "i_printf.h"
-#include "m_misc2.h"
+#include "m_misc.h"
 #include "m_random.h"
 #include "m_swap.h"
+#include "mn_menu.h"
 #include "r_defs.h"
 #include "s_sound.h"
 #include "sounds.h"
@@ -427,10 +428,7 @@ boolean WI_Responder(event_t* ev)
 
 static void WI_DrawString(int y, const char* str)
 {
-  extern void M_DrawString(int x, int y, int color, const char* str);
-  extern int M_GetPixelWidth(const char *str);
-
-  M_DrawString(160 - (M_GetPixelWidth(str) / 2), y, CR_GRAY, str);
+  MN_DrawString(160 - (MN_GetPixelWidth(str) / 2), y, CR_GRAY, str);
 }
 
 
